//---------------------------------------------------------
// QA Navigator Suite
// Copyright  2003,2004 Ronald D. Grindle
//---------------------------------------------------------

using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.IO;
using System.Threading;
using System.Timers;
using System.Windows.Forms;
using System.Xml;

using RG.Basics;
using RG.SQL;
using RG.XMLDB;

using QN.Basics;

namespace QN.TCExer {
	/// <summary>
	/// QA Navigator suite
	/// Copyright  2003,2004 Ronald D. Grindle
	/// 
	/// QA Navigator test case executer GUI
	/// </summary>
	public class frmTCExec : System.Windows.Forms.Form {

		#region my members
    
		/// <summary>
		/// Array of error reports:
		/// 0: "ExCode", 1: "Rep", 2: "RefUID", analog to XML
		/// </summary>
		//2008-02-06 required for resume testing?
		//private ArrayList m_ProbRepLst;

		private bool m_SWIsStarted;

		private	CmpSelPresets m_CmpSelPresets;

		private DataLst m_CmpgnStatLst;

		private int m_HBeatIx;
		private int m_panel1DH, m_grpTCExecDT, m_butCloseDT, m_butErrorDT, m_butNextDT, m_butStartStopDT, m_txtStatDT, m_comboLogDT;

		//private Image[] m_ImgLstHBeat;

		private static SimpleLog m_Logger;
		private StopWatch sWatch;

		private string m_ApplPth;

		private string m_loadUID; // is probably the same as m_uidTC and therfore obsolete
		private string m_uidCmpgn;
		private string m_uidCTC;
		private string m_uidTC;
		private string m_uidTCEx;
		private string m_uidComment;
		private string m_uidRefTstSys;
		private string m_uidTstSys;

		private string m_uidRTCEx;

		private CTCSelPresets m_CTCSelPresets;
		private TCSelPresets m_TCSelPresets;
		
		private QNphrase m_QNphrase;
		private QNpresets m_Presets;
		private QNTools m_QNTools;
		
		private QNGUIservice m_GUIservice;

		private Ref2FileLst m_TProcLst;
		private Ref2FileLst m_TRefLst;
		private Ref2FileLst m_ResFilesLst;

        private RGSQL2 m_DB;
		private XMLDB m_xDB;

		delegate Rslt dlgtFileDialOK( ref string p_FileName );

		#endregion

		#region Form Members

		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.Button butError;
		private System.Windows.Forms.Button butNext;
		private System.Windows.Forms.Button butStartStop;
		private System.Windows.Forms.ComboBox comboExCode;
		private System.Windows.Forms.ComboBox comboTstSys;
		private System.Windows.Forms.GroupBox grpTCExec;
		private System.Windows.Forms.Label lblCampaign;
		private System.Windows.Forms.Label lblDate;
		private System.Windows.Forms.Label lblDesc;
		private System.Windows.Forms.Label lblElapTime;
		private System.Windows.Forms.Label lblExCode;
		private System.Windows.Forms.Label lblPrio;
		private System.Windows.Forms.Label lblTCType;
		private System.Windows.Forms.Label lblTCVer;
		private System.Windows.Forms.Label lblTester;
		private System.Windows.Forms.Label lblTitle;
		private System.Windows.Forms.Label lblTstSys;
		private System.Windows.Forms.Label lblTSysConfig;
		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem menuAbout;
		private System.Windows.Forms.MenuItem menuExit;
		private System.Windows.Forms.MenuItem menuFile;
		private System.Windows.Forms.MenuItem menuHelp;
		private System.Windows.Forms.MenuItem menuItem2;
		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.TextBox txtAuthor;
		private System.Windows.Forms.TextBox txtDate;
		private System.Windows.Forms.TextBox txtDesc;
		private System.Windows.Forms.TextBox txtElapTime;
		private System.Windows.Forms.TextBox txtExpRslt;
		private System.Windows.Forms.TextBox txtStat;
		private System.Windows.Forms.TextBox txtTCPrio;
		private System.Windows.Forms.TextBox txtTCType;
		private System.Windows.Forms.TextBox txtTCVer;
		private System.Windows.Forms.TextBox txtTitle;
		private System.Windows.Forms.TextBox txtTstProc;
		private System.Windows.Forms.ComboBox comboLog;
		private System.Windows.Forms.Label lblTime;
		private System.Windows.Forms.TextBox txtTime;
		private System.Windows.Forms.Label lblComment;
		private System.Windows.Forms.TextBox txtComment;
		private System.Windows.Forms.Label lblSoftRel;
		private System.Windows.Forms.ComboBox comboSoftRel;
		private System.Windows.Forms.Button butClose;
		private System.Windows.Forms.Label lblAppl;
		private System.Windows.Forms.Label lblSection;
		private System.Windows.Forms.TextBox txtAppl;
		private System.Windows.Forms.TextBox txtSection;
		private System.Windows.Forms.MenuItem menuExeTC;
		private System.Windows.Forms.ContextMenu ctxtMenuLog;
		private System.Windows.Forms.MenuItem ctxtLogEntry;
		private System.Windows.Forms.Label lblFctn;
		private System.Windows.Forms.TextBox txtFctn;
		private System.Windows.Forms.Label lblTCSoftRel;
		private System.Windows.Forms.TextBox txtTCSoftRel;
		private System.Windows.Forms.MenuItem menuEditTC;
		private System.Windows.Forms.MenuItem menuRelTC;
		private System.Windows.Forms.MenuItem menuCancel;
		private System.Windows.Forms.MenuItem menuDocu;
		private System.Windows.Forms.MenuItem menuItem3;
		private System.Windows.Forms.TextBox txtCmpgn;
		private System.Windows.Forms.ContextMenu ctxtMenuCmpgn;
		private System.Windows.Forms.MenuItem ctxtCmgnSel;
		private System.Windows.Forms.MenuItem ctxtCmpgnClear;
		private System.Windows.Forms.Timer tmrHBeat;
		private System.Windows.Forms.MenuItem menuPrint;
		private System.Windows.Forms.MenuItem menuItem4;
		private System.Windows.Forms.ImageList imgLstHBeat;
		private System.Windows.Forms.Button butHBeat;
		private System.Windows.Forms.MenuItem menuSelCmpgn;
		private System.Windows.Forms.Label lblResFiles;
		private System.Windows.Forms.ContextMenu ctxtMenuResFiles;
		private System.Windows.Forms.ListBox lstResFiles;
		private System.Windows.Forms.MenuItem ctxtResFileAdd;
		private System.Windows.Forms.MenuItem ctxtResFileRem;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabRsltTxt;
		private System.Windows.Forms.TabPage tabRsltFile;
		private System.Windows.Forms.TabControl tabControl2;
		private System.Windows.Forms.TabPage tabProcTxt;
		private System.Windows.Forms.TabPage tabProcFiles;
		private System.Windows.Forms.ListBox lstTstProcFile;
		private System.Windows.Forms.ListBox lstTstRefFile;
		private System.Windows.Forms.ContextMenu ctxtMenuProc;
		private System.Windows.Forms.MenuItem ctxtProcOpen;
		private System.Windows.Forms.MenuItem ctxtProcName2Clip;
		private System.Windows.Forms.ContextMenu ctxtMenuTstRef;
		private System.Windows.Forms.MenuItem ctxtTstRefOpen;
		private System.Windows.Forms.MenuItem ctxtTstRefName2Clip;
		private System.Windows.Forms.TextBox txtTSysConfig;

		#endregion

		#region I18N

		//-------------------------------------------------------------------------
		private void setLabels() {

			Text = m_QNphrase.lblTCExer;

			grpTCExec.Text = m_QNphrase.lblTCExec;

			lblAppl.Text = m_QNphrase.lblAppl;
			lblCampaign.Text = m_QNphrase.lblCampaign;
			lblComment.Text = m_QNphrase.lblComment;		
			lblDate.Text = m_QNphrase.lblDate;
			lblDesc.Text = m_QNphrase.lblDesc;
			lblElapTime.Text = m_QNphrase.lblElapTime;
			lblExCode.Text = m_QNphrase.lblExCode;
			lblFctn.Text = m_QNphrase.lblFctn;
			lblPrio.Text = m_QNphrase.lblPrio;
			lblResFiles.Text = m_QNphrase.lblResFiles;
			lblSection.Text = m_QNphrase.lblSection;
			lblSoftRel.Text = m_QNphrase.lblRelease;
			lblTCSoftRel.Text = m_QNphrase.lblRelease;
			lblTCType.Text = m_QNphrase.lblTCType;
			lblTCVer.Text = m_QNphrase.lblTCVer;
			lblTester.Text = m_QNphrase.lblTester;
			lblTime.Text =  m_QNphrase.lblTime;
			lblTitle.Text = m_QNphrase.lblTitle;
			lblTstSys.Text = m_QNphrase.lblTstSys;
			lblTSysConfig.Text = m_QNphrase.lblTSysConfig12;
 
			menuAbout.Text = m_QNphrase.mlblAbout;
			menuCancel.Text = m_QNphrase.mlblCancel;
			menuDocu.Text = m_QNphrase.mlblDocu;
			menuEditTC.Text = m_QNphrase.mlblEditTC;
			menuExeTC.Text = m_QNphrase.mlblExeTC;
			menuExit.Text = m_QNphrase.mlblExit;
			menuFile.Text = m_QNphrase.mlblFile;
			menuHelp.Text = m_QNphrase.mlblHelp;
			menuPrint.Text = m_QNphrase.mlblPrint;
			menuRelTC.Text = m_QNphrase.mlblRelTC;
			menuSelCmpgn.Text = m_QNphrase.mlblSelCmpgn;

			tabProcFiles.Text = m_QNphrase.lblFiles;
			tabProcTxt.Text = m_QNphrase.lblTstProc;
			tabRsltFile.Text = m_QNphrase.lblFiles;
			tabRsltTxt.Text = m_QNphrase.lblExpRslt;

			ctxtCmgnSel.Text = m_QNphrase.mlblSel;
			ctxtCmpgnClear.Text = m_QNphrase.mlblClear;
			ctxtLogEntry.Text = m_QNphrase.mlblDispEntry;
			ctxtResFileAdd.Text = m_QNphrase.mlblAdd;
			ctxtResFileRem.Text = m_QNphrase.mlblRemove;
			ctxtTstRefName2Clip.Text = m_QNphrase.mlblName2Clip;
			ctxtTstRefOpen.Text = m_QNphrase.mlblOpen;
			ctxtProcName2Clip.Text = m_QNphrase.mlblName2Clip;
			ctxtProcOpen.Text = m_QNphrase.mlblOpen;

			butError.Text = m_QNphrase.blblErr;
			butClose.Text = m_QNphrase.blblClose;
			butNext.Text = m_QNphrase.blblNext;
			butStartStop.Text = m_QNphrase.blblStart;
		}

		#endregion

		#region window construction/disposal

		// --------------------
		public frmTCExec() {

			try {

				m_Logger = new SimpleLog( "TCExer" );

				InitializeComponent();

				init();
			}
			catch( Exception e ) {
		
				handleExcp( e );
			}
		}

		// --------------------
		public frmTCExec( string p_UID ) {

			try {

				Rslt res;

				m_Logger = new SimpleLog( "TCExer" );

				InitializeComponent();

				res = init();

				if( res.isOK() ) {

					loadTCEx( ref p_UID );
				}
			}
			catch( Exception e ) {
		
				handleExcp( e );
			}
		}

		/// <summary>
		/// Die verwendeten Ressourcen bereinigen.
		/// </summary>
		protected override void Dispose( bool disposing ) {

			if( disposing ) {

				if (components != null) {
					components.Dispose();
				}
                m_DB.close();
			}
			base.Dispose( disposing );
		}

		#endregion

		#region Windows Form Designer generated code
		/// <summary>
		/// Erforderliche Methode fr die Designeruntersttzung. 
		/// Der Inhalt der Methode darf nicht mit dem Code-Editor gendert werden.
		/// </summary>
		private void InitializeComponent() {
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager( typeof( frmTCExec ) );
            this.butStartStop = new System.Windows.Forms.Button();
            this.txtElapTime = new System.Windows.Forms.TextBox();
            this.lblElapTime = new System.Windows.Forms.Label();
            this.lblCampaign = new System.Windows.Forms.Label();
            this.lblTester = new System.Windows.Forms.Label();
            this.txtAuthor = new System.Windows.Forms.TextBox();
            this.lblDate = new System.Windows.Forms.Label();
            this.txtDate = new System.Windows.Forms.TextBox();
            this.grpTCExec = new System.Windows.Forms.GroupBox();
            this.lblResFiles = new System.Windows.Forms.Label();
            this.lstResFiles = new System.Windows.Forms.ListBox();
            this.ctxtMenuResFiles = new System.Windows.Forms.ContextMenu();
            this.ctxtResFileAdd = new System.Windows.Forms.MenuItem();
            this.ctxtResFileRem = new System.Windows.Forms.MenuItem();
            this.butHBeat = new System.Windows.Forms.Button();
            this.imgLstHBeat = new System.Windows.Forms.ImageList( this.components );
            this.txtCmpgn = new System.Windows.Forms.TextBox();
            this.ctxtMenuCmpgn = new System.Windows.Forms.ContextMenu();
            this.ctxtCmgnSel = new System.Windows.Forms.MenuItem();
            this.ctxtCmpgnClear = new System.Windows.Forms.MenuItem();
            this.comboSoftRel = new System.Windows.Forms.ComboBox();
            this.lblSoftRel = new System.Windows.Forms.Label();
            this.txtComment = new System.Windows.Forms.TextBox();
            this.lblComment = new System.Windows.Forms.Label();
            this.txtTime = new System.Windows.Forms.TextBox();
            this.lblTime = new System.Windows.Forms.Label();
            this.lblExCode = new System.Windows.Forms.Label();
            this.comboExCode = new System.Windows.Forms.ComboBox();
            this.comboTstSys = new System.Windows.Forms.ComboBox();
            this.lblTstSys = new System.Windows.Forms.Label();
            this.mainMenu = new System.Windows.Forms.MainMenu( this.components );
            this.menuFile = new System.Windows.Forms.MenuItem();
            this.menuSelCmpgn = new System.Windows.Forms.MenuItem();
            this.menuExeTC = new System.Windows.Forms.MenuItem();
            this.menuEditTC = new System.Windows.Forms.MenuItem();
            this.menuRelTC = new System.Windows.Forms.MenuItem();
            this.menuItem2 = new System.Windows.Forms.MenuItem();
            this.menuPrint = new System.Windows.Forms.MenuItem();
            this.menuItem4 = new System.Windows.Forms.MenuItem();
            this.menuCancel = new System.Windows.Forms.MenuItem();
            this.menuExit = new System.Windows.Forms.MenuItem();
            this.menuHelp = new System.Windows.Forms.MenuItem();
            this.menuDocu = new System.Windows.Forms.MenuItem();
            this.menuItem3 = new System.Windows.Forms.MenuItem();
            this.menuAbout = new System.Windows.Forms.MenuItem();
            this.txtStat = new System.Windows.Forms.TextBox();
            this.txtExpRslt = new System.Windows.Forms.TextBox();
            this.txtTstProc = new System.Windows.Forms.TextBox();
            this.txtTSysConfig = new System.Windows.Forms.TextBox();
            this.lblTSysConfig = new System.Windows.Forms.Label();
            this.txtTCPrio = new System.Windows.Forms.TextBox();
            this.lblPrio = new System.Windows.Forms.Label();
            this.txtDesc = new System.Windows.Forms.TextBox();
            this.lblDesc = new System.Windows.Forms.Label();
            this.txtTCType = new System.Windows.Forms.TextBox();
            this.lblTCType = new System.Windows.Forms.Label();
            this.lblTCVer = new System.Windows.Forms.Label();
            this.txtTCVer = new System.Windows.Forms.TextBox();
            this.lblTitle = new System.Windows.Forms.Label();
            this.txtTitle = new System.Windows.Forms.TextBox();
            this.panel1 = new System.Windows.Forms.Panel();
            this.tabControl2 = new System.Windows.Forms.TabControl();
            this.tabProcTxt = new System.Windows.Forms.TabPage();
            this.tabProcFiles = new System.Windows.Forms.TabPage();
            this.lstTstProcFile = new System.Windows.Forms.ListBox();
            this.ctxtMenuProc = new System.Windows.Forms.ContextMenu();
            this.ctxtProcOpen = new System.Windows.Forms.MenuItem();
            this.ctxtProcName2Clip = new System.Windows.Forms.MenuItem();
            this.tabControl1 = new System.Windows.Forms.TabControl();
            this.tabRsltTxt = new System.Windows.Forms.TabPage();
            this.tabRsltFile = new System.Windows.Forms.TabPage();
            this.lstTstRefFile = new System.Windows.Forms.ListBox();
            this.ctxtMenuTstRef = new System.Windows.Forms.ContextMenu();
            this.ctxtTstRefOpen = new System.Windows.Forms.MenuItem();
            this.ctxtTstRefName2Clip = new System.Windows.Forms.MenuItem();
            this.lblTCSoftRel = new System.Windows.Forms.Label();
            this.txtTCSoftRel = new System.Windows.Forms.TextBox();
            this.lblFctn = new System.Windows.Forms.Label();
            this.txtFctn = new System.Windows.Forms.TextBox();
            this.txtSection = new System.Windows.Forms.TextBox();
            this.txtAppl = new System.Windows.Forms.TextBox();
            this.lblSection = new System.Windows.Forms.Label();
            this.lblAppl = new System.Windows.Forms.Label();
            this.butError = new System.Windows.Forms.Button();
            this.butClose = new System.Windows.Forms.Button();
            this.butNext = new System.Windows.Forms.Button();
            this.comboLog = new System.Windows.Forms.ComboBox();
            this.ctxtMenuLog = new System.Windows.Forms.ContextMenu();
            this.ctxtLogEntry = new System.Windows.Forms.MenuItem();
            this.tmrHBeat = new System.Windows.Forms.Timer( this.components );
            this.grpTCExec.SuspendLayout();
            this.panel1.SuspendLayout();
            this.tabControl2.SuspendLayout();
            this.tabProcTxt.SuspendLayout();
            this.tabProcFiles.SuspendLayout();
            this.tabControl1.SuspendLayout();
            this.tabRsltTxt.SuspendLayout();
            this.tabRsltFile.SuspendLayout();
            this.SuspendLayout();
            // 
            // butStartStop
            // 
            this.butStartStop.BackColor = System.Drawing.SystemColors.Control;
            this.butStartStop.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.butStartStop.Location = new System.Drawing.Point( 462, 853 );
            this.butStartStop.Name = "butStartStop";
            this.butStartStop.Size = new System.Drawing.Size( 123, 29 );
            this.butStartStop.TabIndex = 4;
            this.butStartStop.Text = "&Start";
            this.butStartStop.UseVisualStyleBackColor = false;
            this.butStartStop.MouseLeave += new System.EventHandler( this.butStartStop_MouseLeave );
            this.butStartStop.Click += new System.EventHandler( this.butStartStop_Click );
            this.butStartStop.MouseEnter += new System.EventHandler( this.butStartStop_MouseEnter );
            // 
            // txtElapTime
            // 
            this.txtElapTime.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtElapTime.Location = new System.Drawing.Point( 739, 65 );
            this.txtElapTime.Name = "txtElapTime";
            this.txtElapTime.Size = new System.Drawing.Size( 56, 24 );
            this.txtElapTime.TabIndex = 0;
            this.txtElapTime.TabStop = false;
            this.txtElapTime.Text = "00:00";
            // 
            // lblElapTime
            // 
            this.lblElapTime.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblElapTime.Location = new System.Drawing.Point( 571, 65 );
            this.lblElapTime.Name = "lblElapTime";
            this.lblElapTime.Size = new System.Drawing.Size( 165, 27 );
            this.lblElapTime.TabIndex = 4;
            this.lblElapTime.Text = "Elapsed Time:";
            this.lblElapTime.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblCampaign
            // 
            this.lblCampaign.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblCampaign.Location = new System.Drawing.Point( 11, 31 );
            this.lblCampaign.Name = "lblCampaign";
            this.lblCampaign.Size = new System.Drawing.Size( 165, 24 );
            this.lblCampaign.TabIndex = 6;
            this.lblCampaign.Text = "Campaign";
            this.lblCampaign.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblTester
            // 
            this.lblTester.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTester.Location = new System.Drawing.Point( 571, 31 );
            this.lblTester.Name = "lblTester";
            this.lblTester.Size = new System.Drawing.Size( 165, 24 );
            this.lblTester.TabIndex = 8;
            this.lblTester.Text = "Tester";
            this.lblTester.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtAuthor
            // 
            this.txtAuthor.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtAuthor.Location = new System.Drawing.Point( 739, 30 );
            this.txtAuthor.Name = "txtAuthor";
            this.txtAuthor.Size = new System.Drawing.Size( 252, 24 );
            this.txtAuthor.TabIndex = 0;
            this.txtAuthor.TabStop = false;
            this.txtAuthor.Text = "xxx";
            // 
            // lblDate
            // 
            this.lblDate.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblDate.Location = new System.Drawing.Point( 382, 31 );
            this.lblDate.Name = "lblDate";
            this.lblDate.Size = new System.Drawing.Size( 63, 24 );
            this.lblDate.TabIndex = 10;
            this.lblDate.Text = "Date";
            this.lblDate.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtDate
            // 
            this.txtDate.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtDate.Location = new System.Drawing.Point( 449, 30 );
            this.txtDate.Name = "txtDate";
            this.txtDate.Size = new System.Drawing.Size( 101, 24 );
            this.txtDate.TabIndex = 0;
            this.txtDate.TabStop = false;
            this.txtDate.Text = "2003-09-11";
            // 
            // grpTCExec
            // 
            this.grpTCExec.Controls.Add( this.lblResFiles );
            this.grpTCExec.Controls.Add( this.lstResFiles );
            this.grpTCExec.Controls.Add( this.butHBeat );
            this.grpTCExec.Controls.Add( this.txtCmpgn );
            this.grpTCExec.Controls.Add( this.comboSoftRel );
            this.grpTCExec.Controls.Add( this.lblSoftRel );
            this.grpTCExec.Controls.Add( this.txtComment );
            this.grpTCExec.Controls.Add( this.lblComment );
            this.grpTCExec.Controls.Add( this.txtTime );
            this.grpTCExec.Controls.Add( this.lblTime );
            this.grpTCExec.Controls.Add( this.lblExCode );
            this.grpTCExec.Controls.Add( this.comboExCode );
            this.grpTCExec.Controls.Add( this.comboTstSys );
            this.grpTCExec.Controls.Add( this.lblTstSys );
            this.grpTCExec.Controls.Add( this.txtAuthor );
            this.grpTCExec.Controls.Add( this.lblTester );
            this.grpTCExec.Controls.Add( this.lblDate );
            this.grpTCExec.Controls.Add( this.txtDate );
            this.grpTCExec.Controls.Add( this.lblCampaign );
            this.grpTCExec.Controls.Add( this.txtElapTime );
            this.grpTCExec.Controls.Add( this.lblElapTime );
            this.grpTCExec.Location = new System.Drawing.Point( 8, 618 );
            this.grpTCExec.Name = "grpTCExec";
            this.grpTCExec.Size = new System.Drawing.Size( 999, 225 );
            this.grpTCExec.TabIndex = 19;
            this.grpTCExec.TabStop = false;
            this.grpTCExec.Text = "TC Execution";
            // 
            // lblResFiles
            // 
            this.lblResFiles.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblResFiles.Location = new System.Drawing.Point( 13, 192 );
            this.lblResFiles.Name = "lblResFiles";
            this.lblResFiles.Size = new System.Drawing.Size( 133, 26 );
            this.lblResFiles.TabIndex = 22;
            this.lblResFiles.Text = "Rslt files";
            this.lblResFiles.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lstResFiles
            // 
            this.lstResFiles.ContextMenu = this.ctxtMenuResFiles;
            this.lstResFiles.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lstResFiles.ItemHeight = 18;
            this.lstResFiles.Location = new System.Drawing.Point( 153, 193 );
            this.lstResFiles.MinimumSize = new System.Drawing.Size( 599, 19 );
            this.lstResFiles.Name = "lstResFiles";
            this.lstResFiles.ScrollAlwaysVisible = true;
            this.lstResFiles.Size = new System.Drawing.Size( 838, 4 );
            this.lstResFiles.TabIndex = 21;
            // 
            // ctxtMenuResFiles
            // 
            this.ctxtMenuResFiles.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.ctxtResFileAdd,
            this.ctxtResFileRem} );
            this.ctxtMenuResFiles.Popup += new System.EventHandler( this.ctxtMenuResFiles_Popup );
            // 
            // ctxtResFileAdd
            // 
            this.ctxtResFileAdd.Index = 0;
            this.ctxtResFileAdd.Text = "add";
            this.ctxtResFileAdd.Click += new System.EventHandler( this.ctxtResFileAdd_Click );
            // 
            // ctxtResFileRem
            // 
            this.ctxtResFileRem.Index = 1;
            this.ctxtResFileRem.Text = "remove";
            this.ctxtResFileRem.Click += new System.EventHandler( this.ctxtResFileRem_Click );
            // 
            // butHBeat
            // 
            this.butHBeat.BackColor = System.Drawing.SystemColors.WindowFrame;
            this.butHBeat.ImageIndex = 0;
            this.butHBeat.ImageList = this.imgLstHBeat;
            this.butHBeat.Location = new System.Drawing.Point( 827, 62 );
            this.butHBeat.Name = "butHBeat";
            this.butHBeat.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.butHBeat.Size = new System.Drawing.Size( 38, 34 );
            this.butHBeat.TabIndex = 20;
            this.butHBeat.TabStop = false;
            this.butHBeat.UseVisualStyleBackColor = false;
            // 
            // imgLstHBeat
            // 
            this.imgLstHBeat.ImageStream = ( (System.Windows.Forms.ImageListStreamer)( resources.GetObject( "imgLstHBeat.ImageStream" ) ) );
            this.imgLstHBeat.TransparentColor = System.Drawing.Color.Transparent;
            this.imgLstHBeat.Images.SetKeyName( 0, "" );
            this.imgLstHBeat.Images.SetKeyName( 1, "" );
            this.imgLstHBeat.Images.SetKeyName( 2, "" );
            this.imgLstHBeat.Images.SetKeyName( 3, "" );
            this.imgLstHBeat.Images.SetKeyName( 4, "" );
            this.imgLstHBeat.Images.SetKeyName( 5, "" );
            this.imgLstHBeat.Images.SetKeyName( 6, "" );
            this.imgLstHBeat.Images.SetKeyName( 7, "" );
            this.imgLstHBeat.Images.SetKeyName( 8, "" );
            this.imgLstHBeat.Images.SetKeyName( 9, "" );
            this.imgLstHBeat.Images.SetKeyName( 10, "" );
            this.imgLstHBeat.Images.SetKeyName( 11, "" );
            this.imgLstHBeat.Images.SetKeyName( 12, "" );
            this.imgLstHBeat.Images.SetKeyName( 13, "" );
            // 
            // txtCmpgn
            // 
            this.txtCmpgn.BackColor = System.Drawing.SystemColors.Window;
            this.txtCmpgn.ContextMenu = this.ctxtMenuCmpgn;
            this.txtCmpgn.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtCmpgn.Location = new System.Drawing.Point( 153, 30 );
            this.txtCmpgn.Name = "txtCmpgn";
            this.txtCmpgn.ReadOnly = true;
            this.txtCmpgn.Size = new System.Drawing.Size( 211, 24 );
            this.txtCmpgn.TabIndex = 19;
            // 
            // ctxtMenuCmpgn
            // 
            this.ctxtMenuCmpgn.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.ctxtCmgnSel,
            this.ctxtCmpgnClear} );
            // 
            // ctxtCmgnSel
            // 
            this.ctxtCmgnSel.Index = 0;
            this.ctxtCmgnSel.Text = "select cmpgn";
            this.ctxtCmgnSel.Click += new System.EventHandler( this.ctxtCmgnSel_Click );
            // 
            // ctxtCmpgnClear
            // 
            this.ctxtCmpgnClear.Index = 1;
            this.ctxtCmpgnClear.Text = "clear";
            this.ctxtCmpgnClear.Click += new System.EventHandler( this.ctxtCmpgnClear_Click );
            // 
            // comboSoftRel
            // 
            this.comboSoftRel.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboSoftRel.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.comboSoftRel.Location = new System.Drawing.Point( 153, 100 );
            this.comboSoftRel.Name = "comboSoftRel";
            this.comboSoftRel.Size = new System.Drawing.Size( 211, 26 );
            this.comboSoftRel.TabIndex = 2;
            // 
            // lblSoftRel
            // 
            this.lblSoftRel.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblSoftRel.Location = new System.Drawing.Point( 11, 103 );
            this.lblSoftRel.Name = "lblSoftRel";
            this.lblSoftRel.Size = new System.Drawing.Size( 165, 24 );
            this.lblSoftRel.TabIndex = 18;
            this.lblSoftRel.Text = "Software Release";
            this.lblSoftRel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtComment
            // 
            this.txtComment.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtComment.Location = new System.Drawing.Point( 153, 135 );
            this.txtComment.Multiline = true;
            this.txtComment.Name = "txtComment";
            this.txtComment.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtComment.Size = new System.Drawing.Size( 838, 50 );
            this.txtComment.TabIndex = 3;
            this.txtComment.DoubleClick += new System.EventHandler( this.txtComment_DoubleClick );
            // 
            // lblComment
            // 
            this.lblComment.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblComment.Location = new System.Drawing.Point( 11, 139 );
            this.lblComment.Name = "lblComment";
            this.lblComment.Size = new System.Drawing.Size( 165, 25 );
            this.lblComment.TabIndex = 16;
            this.lblComment.Text = "Comment";
            this.lblComment.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtTime
            // 
            this.txtTime.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTime.Location = new System.Drawing.Point( 449, 65 );
            this.txtTime.Name = "txtTime";
            this.txtTime.Size = new System.Drawing.Size( 56, 24 );
            this.txtTime.TabIndex = 0;
            this.txtTime.TabStop = false;
            this.txtTime.Text = "00:00";
            // 
            // lblTime
            // 
            this.lblTime.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTime.Location = new System.Drawing.Point( 382, 66 );
            this.lblTime.Name = "lblTime";
            this.lblTime.Size = new System.Drawing.Size( 63, 25 );
            this.lblTime.TabIndex = 15;
            this.lblTime.Text = "Time";
            this.lblTime.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblExCode
            // 
            this.lblExCode.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblExCode.Location = new System.Drawing.Point( 571, 103 );
            this.lblExCode.Name = "lblExCode";
            this.lblExCode.Size = new System.Drawing.Size( 165, 24 );
            this.lblExCode.TabIndex = 14;
            this.lblExCode.Text = "Execution Code";
            this.lblExCode.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // comboExCode
            // 
            this.comboExCode.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboExCode.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.comboExCode.Location = new System.Drawing.Point( 739, 100 );
            this.comboExCode.Name = "comboExCode";
            this.comboExCode.Size = new System.Drawing.Size( 252, 26 );
            this.comboExCode.TabIndex = 6;
            // 
            // comboTstSys
            // 
            this.comboTstSys.AllowDrop = true;
            this.comboTstSys.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboTstSys.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.comboTstSys.Location = new System.Drawing.Point( 153, 64 );
            this.comboTstSys.Name = "comboTstSys";
            this.comboTstSys.Size = new System.Drawing.Size( 211, 26 );
            this.comboTstSys.TabIndex = 1;
            // 
            // lblTstSys
            // 
            this.lblTstSys.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTstSys.Location = new System.Drawing.Point( 11, 65 );
            this.lblTstSys.Name = "lblTstSys";
            this.lblTstSys.Size = new System.Drawing.Size( 165, 27 );
            this.lblTstSys.TabIndex = 12;
            this.lblTstSys.Text = "Test System";
            this.lblTstSys.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // mainMenu
            // 
            this.mainMenu.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.menuFile,
            this.menuHelp} );
            // 
            // menuFile
            // 
            this.menuFile.Index = 0;
            this.menuFile.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.menuSelCmpgn,
            this.menuExeTC,
            this.menuEditTC,
            this.menuRelTC,
            this.menuItem2,
            this.menuPrint,
            this.menuItem4,
            this.menuCancel,
            this.menuExit} );
            this.menuFile.Text = "File";
            // 
            // menuSelCmpgn
            // 
            this.menuSelCmpgn.Index = 0;
            this.menuSelCmpgn.Text = "SelCamp";
            this.menuSelCmpgn.Click += new System.EventHandler( this.menuSelCmpgn_Click );
            // 
            // menuExeTC
            // 
            this.menuExeTC.Index = 1;
            this.menuExeTC.Text = "Execute TC";
            this.menuExeTC.Click += new System.EventHandler( this.menuExeTC_Click );
            // 
            // menuEditTC
            // 
            this.menuEditTC.Enabled = false;
            this.menuEditTC.Index = 2;
            this.menuEditTC.Text = "Edit This TC";
            this.menuEditTC.Click += new System.EventHandler( this.menuEditTC_Click );
            // 
            // menuRelTC
            // 
            this.menuRelTC.Enabled = false;
            this.menuRelTC.Index = 3;
            this.menuRelTC.Text = "Reload TC";
            this.menuRelTC.Click += new System.EventHandler( this.menuRelTC_Click );
            // 
            // menuItem2
            // 
            this.menuItem2.Index = 4;
            this.menuItem2.Text = "-";
            // 
            // menuPrint
            // 
            this.menuPrint.Enabled = false;
            this.menuPrint.Index = 5;
            this.menuPrint.Text = "Print";
            this.menuPrint.Click += new System.EventHandler( this.menuPrint_Click );
            // 
            // menuItem4
            // 
            this.menuItem4.Index = 6;
            this.menuItem4.Text = "-";
            // 
            // menuCancel
            // 
            this.menuCancel.Enabled = false;
            this.menuCancel.Index = 7;
            this.menuCancel.Text = "Cancel";
            this.menuCancel.Click += new System.EventHandler( this.menuCancel_Click );
            // 
            // menuExit
            // 
            this.menuExit.Index = 8;
            this.menuExit.Text = "Exit";
            this.menuExit.Click += new System.EventHandler( this.menuExit_Click );
            // 
            // menuHelp
            // 
            this.menuHelp.Index = 1;
            this.menuHelp.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.menuDocu,
            this.menuItem3,
            this.menuAbout} );
            this.menuHelp.Text = "Help";
            // 
            // menuDocu
            // 
            this.menuDocu.Index = 0;
            this.menuDocu.Text = "Docu";
            this.menuDocu.Click += new System.EventHandler( this.menuDocu_Click );
            // 
            // menuItem3
            // 
            this.menuItem3.Index = 1;
            this.menuItem3.Text = "-";
            // 
            // menuAbout
            // 
            this.menuAbout.Index = 2;
            this.menuAbout.Text = "About";
            this.menuAbout.Click += new System.EventHandler( this.menuAbout_Click );
            // 
            // txtStat
            // 
            this.txtStat.BackColor = System.Drawing.Color.Yellow;
            this.txtStat.Font = new System.Drawing.Font( "Microsoft Sans Serif", 10F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtStat.Location = new System.Drawing.Point( 6, 895 );
            this.txtStat.Name = "txtStat";
            this.txtStat.ReadOnly = true;
            this.txtStat.Size = new System.Drawing.Size( 128, 26 );
            this.txtStat.TabIndex = 0;
            this.txtStat.TabStop = false;
            this.txtStat.Text = "Initializing...";
            this.txtStat.TextAlign = System.Windows.Forms.HorizontalAlignment.Center;
            // 
            // txtExpRslt
            // 
            this.txtExpRslt.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtExpRslt.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtExpRslt.Location = new System.Drawing.Point( 0, 2 );
            this.txtExpRslt.Multiline = true;
            this.txtExpRslt.Name = "txtExpRslt";
            this.txtExpRslt.ReadOnly = true;
            this.txtExpRslt.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtExpRslt.Size = new System.Drawing.Size( 944, 98 );
            this.txtExpRslt.TabIndex = 0;
            this.txtExpRslt.TabStop = false;
            this.txtExpRslt.Text = "Expected Rslt";
            this.txtExpRslt.DoubleClick += new System.EventHandler( this.txtExpRslt_DoubleClick );
            // 
            // txtTstProc
            // 
            this.txtTstProc.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTstProc.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTstProc.Location = new System.Drawing.Point( 0, 0 );
            this.txtTstProc.Multiline = true;
            this.txtTstProc.Name = "txtTstProc";
            this.txtTstProc.ReadOnly = true;
            this.txtTstProc.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtTstProc.Size = new System.Drawing.Size( 944, 118 );
            this.txtTstProc.TabIndex = 0;
            this.txtTstProc.TabStop = false;
            this.txtTstProc.Text = "Test Procedure";
            this.txtTstProc.DoubleClick += new System.EventHandler( this.txtTstProc_DoubleClick );
            // 
            // txtTSysConfig
            // 
            this.txtTSysConfig.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTSysConfig.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTSysConfig.Location = new System.Drawing.Point( 500, 150 );
            this.txtTSysConfig.Name = "txtTSysConfig";
            this.txtTSysConfig.ReadOnly = true;
            this.txtTSysConfig.Size = new System.Drawing.Size( 462, 24 );
            this.txtTSysConfig.TabIndex = 0;
            this.txtTSysConfig.TabStop = false;
            this.txtTSysConfig.Text = "TSysConf";
            // 
            // lblTSysConfig
            // 
            this.lblTSysConfig.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTSysConfig.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblTSysConfig.Location = new System.Drawing.Point( 336, 142 );
            this.lblTSysConfig.Name = "lblTSysConfig";
            this.lblTSysConfig.Size = new System.Drawing.Size( 155, 43 );
            this.lblTSysConfig.TabIndex = 0;
            this.lblTSysConfig.Text = "Test System Configuration";
            this.lblTSysConfig.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtTCPrio
            // 
            this.txtTCPrio.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTCPrio.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTCPrio.Location = new System.Drawing.Point( 857, 44 );
            this.txtTCPrio.Name = "txtTCPrio";
            this.txtTCPrio.ReadOnly = true;
            this.txtTCPrio.Size = new System.Drawing.Size( 106, 24 );
            this.txtTCPrio.TabIndex = 0;
            this.txtTCPrio.TabStop = false;
            this.txtTCPrio.Text = "X";
            // 
            // lblPrio
            // 
            this.lblPrio.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblPrio.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblPrio.Location = new System.Drawing.Point( 748, 44 );
            this.lblPrio.Name = "lblPrio";
            this.lblPrio.Size = new System.Drawing.Size( 105, 27 );
            this.lblPrio.TabIndex = 18;
            this.lblPrio.Text = "Priority";
            this.lblPrio.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtDesc
            // 
            this.txtDesc.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtDesc.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtDesc.Location = new System.Drawing.Point( 13, 209 );
            this.txtDesc.Multiline = true;
            this.txtDesc.Name = "txtDesc";
            this.txtDesc.ReadOnly = true;
            this.txtDesc.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtDesc.Size = new System.Drawing.Size( 953, 74 );
            this.txtDesc.TabIndex = 0;
            this.txtDesc.TabStop = false;
            this.txtDesc.Text = "Desc";
            this.txtDesc.DoubleClick += new System.EventHandler( this.txtDesc_DoubleClick );
            // 
            // lblDesc
            // 
            this.lblDesc.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblDesc.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblDesc.Location = new System.Drawing.Point( 13, 185 );
            this.lblDesc.Name = "lblDesc";
            this.lblDesc.Size = new System.Drawing.Size( 168, 19 );
            this.lblDesc.TabIndex = 0;
            this.lblDesc.Text = "Description";
            // 
            // txtTCType
            // 
            this.txtTCType.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTCType.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTCType.Location = new System.Drawing.Point( 123, 150 );
            this.txtTCType.Name = "txtTCType";
            this.txtTCType.ReadOnly = true;
            this.txtTCType.Size = new System.Drawing.Size( 202, 24 );
            this.txtTCType.TabIndex = 0;
            this.txtTCType.TabStop = false;
            this.txtTCType.Text = "TC type";
            // 
            // lblTCType
            // 
            this.lblTCType.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTCType.Location = new System.Drawing.Point( 11, 150 );
            this.lblTCType.Name = "lblTCType";
            this.lblTCType.Size = new System.Drawing.Size( 112, 27 );
            this.lblTCType.TabIndex = 16;
            this.lblTCType.Text = "Type";
            this.lblTCType.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblTCVer
            // 
            this.lblTCVer.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTCVer.Location = new System.Drawing.Point( 748, 11 );
            this.lblTCVer.Name = "lblTCVer";
            this.lblTCVer.Size = new System.Drawing.Size( 105, 27 );
            this.lblTCVer.TabIndex = 14;
            this.lblTCVer.Text = "Version";
            this.lblTCVer.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtTCVer
            // 
            this.txtTCVer.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTCVer.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTCVer.Location = new System.Drawing.Point( 857, 11 );
            this.txtTCVer.Name = "txtTCVer";
            this.txtTCVer.ReadOnly = true;
            this.txtTCVer.Size = new System.Drawing.Size( 106, 24 );
            this.txtTCVer.TabIndex = 0;
            this.txtTCVer.TabStop = false;
            this.txtTCVer.Text = "v1.0";
            // 
            // lblTitle
            // 
            this.lblTitle.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTitle.Location = new System.Drawing.Point( 11, 11 );
            this.lblTitle.Name = "lblTitle";
            this.lblTitle.Size = new System.Drawing.Size( 112, 27 );
            this.lblTitle.TabIndex = 12;
            this.lblTitle.Text = "Title";
            this.lblTitle.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtTitle
            // 
            this.txtTitle.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTitle.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTitle.Location = new System.Drawing.Point( 123, 11 );
            this.txtTitle.Name = "txtTitle";
            this.txtTitle.ReadOnly = true;
            this.txtTitle.Size = new System.Drawing.Size( 616, 24 );
            this.txtTitle.TabIndex = 0;
            this.txtTitle.TabStop = false;
            this.txtTitle.Text = "Title";
            // 
            // panel1
            // 
            this.panel1.AutoScroll = true;
            this.panel1.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
            this.panel1.Controls.Add( this.tabControl2 );
            this.panel1.Controls.Add( this.tabControl1 );
            this.panel1.Controls.Add( this.lblTCSoftRel );
            this.panel1.Controls.Add( this.txtTCSoftRel );
            this.panel1.Controls.Add( this.lblFctn );
            this.panel1.Controls.Add( this.txtFctn );
            this.panel1.Controls.Add( this.txtSection );
            this.panel1.Controls.Add( this.txtAppl );
            this.panel1.Controls.Add( this.lblSection );
            this.panel1.Controls.Add( this.lblAppl );
            this.panel1.Controls.Add( this.lblTCVer );
            this.panel1.Controls.Add( this.txtTCVer );
            this.panel1.Controls.Add( this.txtTSysConfig );
            this.panel1.Controls.Add( this.lblTSysConfig );
            this.panel1.Controls.Add( this.txtTCPrio );
            this.panel1.Controls.Add( this.lblPrio );
            this.panel1.Controls.Add( this.txtTCType );
            this.panel1.Controls.Add( this.lblTCType );
            this.panel1.Controls.Add( this.lblDesc );
            this.panel1.Controls.Add( this.txtDesc );
            this.panel1.Controls.Add( this.lblTitle );
            this.panel1.Controls.Add( this.txtTitle );
            this.panel1.Font = new System.Drawing.Font( "Microsoft Sans Serif", 10F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.panel1.Location = new System.Drawing.Point( 3, 2 );
            this.panel1.Name = "panel1";
            this.panel1.Size = new System.Drawing.Size( 1005, 607 );
            this.panel1.TabIndex = 34;
            // 
            // tabControl2
            // 
            this.tabControl2.Controls.Add( this.tabProcTxt );
            this.tabControl2.Controls.Add( this.tabProcFiles );
            this.tabControl2.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.tabControl2.Location = new System.Drawing.Point( 8, 292 );
            this.tabControl2.Name = "tabControl2";
            this.tabControl2.SelectedIndex = 0;
            this.tabControl2.Size = new System.Drawing.Size( 958, 155 );
            this.tabControl2.TabIndex = 34;
            // 
            // tabProcTxt
            // 
            this.tabProcTxt.Controls.Add( this.txtTstProc );
            this.tabProcTxt.Location = new System.Drawing.Point( 4, 27 );
            this.tabProcTxt.Name = "tabProcTxt";
            this.tabProcTxt.Size = new System.Drawing.Size( 950, 124 );
            this.tabProcTxt.TabIndex = 0;
            this.tabProcTxt.Text = "Procedure";
            // 
            // tabProcFiles
            // 
            this.tabProcFiles.Controls.Add( this.lstTstProcFile );
            this.tabProcFiles.Location = new System.Drawing.Point( 4, 27 );
            this.tabProcFiles.Name = "tabProcFiles";
            this.tabProcFiles.Size = new System.Drawing.Size( 950, 124 );
            this.tabProcFiles.TabIndex = 1;
            this.tabProcFiles.Text = "Files";
            // 
            // lstTstProcFile
            // 
            this.lstTstProcFile.BackColor = System.Drawing.Color.LightSteelBlue;
            this.lstTstProcFile.ContextMenu = this.ctxtMenuProc;
            this.lstTstProcFile.ItemHeight = 18;
            this.lstTstProcFile.Location = new System.Drawing.Point( 0, 10 );
            this.lstTstProcFile.Name = "lstTstProcFile";
            this.lstTstProcFile.ScrollAlwaysVisible = true;
            this.lstTstProcFile.Size = new System.Drawing.Size( 944, 58 );
            this.lstTstProcFile.TabIndex = 0;
            // 
            // ctxtMenuProc
            // 
            this.ctxtMenuProc.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.ctxtProcOpen,
            this.ctxtProcName2Clip} );
            this.ctxtMenuProc.Popup += new System.EventHandler( this.ctxtMenuProc_Popup );
            // 
            // ctxtProcOpen
            // 
            this.ctxtProcOpen.Index = 0;
            this.ctxtProcOpen.Text = "open";
            this.ctxtProcOpen.Click += new System.EventHandler( this.ctxtProcOpen_Click );
            // 
            // ctxtProcName2Clip
            // 
            this.ctxtProcName2Clip.Index = 1;
            this.ctxtProcName2Clip.Text = "name 2 clipboard";
            this.ctxtProcName2Clip.Click += new System.EventHandler( this.ctxtProcName2Clip_Click );
            // 
            // tabControl1
            // 
            this.tabControl1.Controls.Add( this.tabRsltTxt );
            this.tabControl1.Controls.Add( this.tabRsltFile );
            this.tabControl1.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.tabControl1.Location = new System.Drawing.Point( 8, 460 );
            this.tabControl1.Name = "tabControl1";
            this.tabControl1.SelectedIndex = 0;
            this.tabControl1.Size = new System.Drawing.Size( 958, 136 );
            this.tabControl1.TabIndex = 33;
            // 
            // tabRsltTxt
            // 
            this.tabRsltTxt.Controls.Add( this.txtExpRslt );
            this.tabRsltTxt.Location = new System.Drawing.Point( 4, 27 );
            this.tabRsltTxt.Name = "tabRsltTxt";
            this.tabRsltTxt.Size = new System.Drawing.Size( 950, 105 );
            this.tabRsltTxt.TabIndex = 0;
            this.tabRsltTxt.Text = "Expected Reult";
            // 
            // tabRsltFile
            // 
            this.tabRsltFile.Controls.Add( this.lstTstRefFile );
            this.tabRsltFile.Location = new System.Drawing.Point( 4, 27 );
            this.tabRsltFile.Name = "tabRsltFile";
            this.tabRsltFile.Size = new System.Drawing.Size( 950, 105 );
            this.tabRsltFile.TabIndex = 1;
            this.tabRsltFile.Text = "Files";
            // 
            // lstTstRefFile
            // 
            this.lstTstRefFile.BackColor = System.Drawing.Color.LightSteelBlue;
            this.lstTstRefFile.ContextMenu = this.ctxtMenuTstRef;
            this.lstTstRefFile.ItemHeight = 18;
            this.lstTstRefFile.Location = new System.Drawing.Point( 1, 10 );
            this.lstTstRefFile.Name = "lstTstRefFile";
            this.lstTstRefFile.ScrollAlwaysVisible = true;
            this.lstTstRefFile.Size = new System.Drawing.Size( 944, 40 );
            this.lstTstRefFile.TabIndex = 1;
            // 
            // ctxtMenuTstRef
            // 
            this.ctxtMenuTstRef.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.ctxtTstRefOpen,
            this.ctxtTstRefName2Clip} );
            this.ctxtMenuTstRef.Popup += new System.EventHandler( this.ctxtMenuTstRef_Popup );
            // 
            // ctxtTstRefOpen
            // 
            this.ctxtTstRefOpen.Index = 0;
            this.ctxtTstRefOpen.Text = "open";
            this.ctxtTstRefOpen.Click += new System.EventHandler( this.ctxtTstRefOpen_Click );
            // 
            // ctxtTstRefName2Clip
            // 
            this.ctxtTstRefName2Clip.Index = 1;
            this.ctxtTstRefName2Clip.Text = "name 2 clipboard";
            this.ctxtTstRefName2Clip.Click += new System.EventHandler( this.ctxtTstRefName2Clip_Click );
            // 
            // lblTCSoftRel
            // 
            this.lblTCSoftRel.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblTCSoftRel.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblTCSoftRel.Location = new System.Drawing.Point( 748, 81 );
            this.lblTCSoftRel.Name = "lblTCSoftRel";
            this.lblTCSoftRel.Size = new System.Drawing.Size( 105, 24 );
            this.lblTCSoftRel.TabIndex = 32;
            this.lblTCSoftRel.Text = "Release";
            this.lblTCSoftRel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtTCSoftRel
            // 
            this.txtTCSoftRel.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtTCSoftRel.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtTCSoftRel.Location = new System.Drawing.Point( 857, 79 );
            this.txtTCSoftRel.Name = "txtTCSoftRel";
            this.txtTCSoftRel.ReadOnly = true;
            this.txtTCSoftRel.Size = new System.Drawing.Size( 106, 24 );
            this.txtTCSoftRel.TabIndex = 31;
            this.txtTCSoftRel.Text = "V99.99.999";
            // 
            // lblFctn
            // 
            this.lblFctn.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblFctn.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblFctn.Location = new System.Drawing.Point( 11, 116 );
            this.lblFctn.Name = "lblFctn";
            this.lblFctn.Size = new System.Drawing.Size( 112, 27 );
            this.lblFctn.TabIndex = 30;
            this.lblFctn.Text = "Function";
            this.lblFctn.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // txtFctn
            // 
            this.txtFctn.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtFctn.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtFctn.Location = new System.Drawing.Point( 123, 116 );
            this.txtFctn.Name = "txtFctn";
            this.txtFctn.ReadOnly = true;
            this.txtFctn.Size = new System.Drawing.Size( 616, 24 );
            this.txtFctn.TabIndex = 29;
            this.txtFctn.TabStop = false;
            this.txtFctn.Text = "Function";
            // 
            // txtSection
            // 
            this.txtSection.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtSection.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtSection.Location = new System.Drawing.Point( 123, 44 );
            this.txtSection.Name = "txtSection";
            this.txtSection.ReadOnly = true;
            this.txtSection.Size = new System.Drawing.Size( 616, 24 );
            this.txtSection.TabIndex = 0;
            this.txtSection.TabStop = false;
            this.txtSection.Text = "Section";
            // 
            // txtAppl
            // 
            this.txtAppl.BackColor = System.Drawing.Color.LightSteelBlue;
            this.txtAppl.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.txtAppl.Location = new System.Drawing.Point( 123, 79 );
            this.txtAppl.Name = "txtAppl";
            this.txtAppl.ReadOnly = true;
            this.txtAppl.Size = new System.Drawing.Size( 616, 24 );
            this.txtAppl.TabIndex = 0;
            this.txtAppl.TabStop = false;
            this.txtAppl.Text = "Appl";
            // 
            // lblSection
            // 
            this.lblSection.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblSection.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblSection.Location = new System.Drawing.Point( 11, 44 );
            this.lblSection.Name = "lblSection";
            this.lblSection.Size = new System.Drawing.Size( 112, 27 );
            this.lblSection.TabIndex = 26;
            this.lblSection.Text = "Section";
            this.lblSection.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblAppl
            // 
            this.lblAppl.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.lblAppl.ImeMode = System.Windows.Forms.ImeMode.NoControl;
            this.lblAppl.Location = new System.Drawing.Point( 11, 79 );
            this.lblAppl.Name = "lblAppl";
            this.lblAppl.Size = new System.Drawing.Size( 112, 27 );
            this.lblAppl.TabIndex = 25;
            this.lblAppl.Text = "Application";
            this.lblAppl.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // butError
            // 
            this.butError.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.butError.Location = new System.Drawing.Point( 601, 853 );
            this.butError.Name = "butError";
            this.butError.Size = new System.Drawing.Size( 123, 29 );
            this.butError.TabIndex = 5;
            this.butError.Text = "&Error";
            this.butError.MouseLeave += new System.EventHandler( this.butError_MouseLeave );
            this.butError.Click += new System.EventHandler( this.butError_Click );
            this.butError.MouseEnter += new System.EventHandler( this.butError_MouseEnter );
            // 
            // butClose
            // 
            this.butClose.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.butClose.Location = new System.Drawing.Point( 739, 853 );
            this.butClose.Name = "butClose";
            this.butClose.Size = new System.Drawing.Size( 123, 29 );
            this.butClose.TabIndex = 7;
            this.butClose.Text = "&Close";
            this.butClose.MouseLeave += new System.EventHandler( this.butClose_MouseLeave );
            this.butClose.Click += new System.EventHandler( this.butClose_Click );
            this.butClose.MouseEnter += new System.EventHandler( this.butClose_MouseEnter );
            // 
            // butNext
            // 
            this.butNext.Font = new System.Drawing.Font( "Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.butNext.Location = new System.Drawing.Point( 882, 853 );
            this.butNext.Name = "butNext";
            this.butNext.Size = new System.Drawing.Size( 123, 29 );
            this.butNext.TabIndex = 8;
            this.butNext.Text = "&Next";
            this.butNext.Visible = false;
            this.butNext.MouseLeave += new System.EventHandler( this.butNext_MouseLeave );
            this.butNext.Click += new System.EventHandler( this.butNext_Click );
            this.butNext.MouseEnter += new System.EventHandler( this.butNext_MouseEnter );
            // 
            // comboLog
            // 
            this.comboLog.ContextMenu = this.ctxtMenuLog;
            this.comboLog.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboLog.Font = new System.Drawing.Font( "Microsoft Sans Serif", 10F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.comboLog.ItemHeight = 20;
            this.comboLog.Location = new System.Drawing.Point( 140, 895 );
            this.comboLog.Name = "comboLog";
            this.comboLog.Size = new System.Drawing.Size( 868, 28 );
            this.comboLog.TabIndex = 35;
            this.comboLog.TabStop = false;
            // 
            // ctxtMenuLog
            // 
            this.ctxtMenuLog.MenuItems.AddRange( new System.Windows.Forms.MenuItem[] {
            this.ctxtLogEntry} );
            // 
            // ctxtLogEntry
            // 
            this.ctxtLogEntry.Index = 0;
            this.ctxtLogEntry.Text = "Display Entry";
            this.ctxtLogEntry.Click += new System.EventHandler( this.ctxtLogEntry_Click );
            // 
            // tmrHBeat
            // 
            this.tmrHBeat.Interval = 175;
            this.tmrHBeat.Tick += new System.EventHandler( this.tmrHBeat_Tick );
            // 
            // frmTCExec
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size( 7, 16 );
            this.ClientSize = new System.Drawing.Size( 1017, 765 );
            this.Controls.Add( this.comboLog );
            this.Controls.Add( this.butNext );
            this.Controls.Add( this.butClose );
            this.Controls.Add( this.butError );
            this.Controls.Add( this.txtStat );
            this.Controls.Add( this.grpTCExec );
            this.Controls.Add( this.panel1 );
            this.Controls.Add( this.butStartStop );
            this.Font = new System.Drawing.Font( "Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ( (byte)( 0 ) ) );
            this.Icon = ( (System.Drawing.Icon)( resources.GetObject( "$this.Icon" ) ) );
            this.MaximizeBox = false;
            this.Menu = this.mainMenu;
            this.MinimumSize = new System.Drawing.Size( 1025, 805 );
            this.Name = "frmTCExec";
            this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Show;
            this.Text = "u";
            this.Resize += new System.EventHandler( this.frmTCExec_Resize );
            this.grpTCExec.ResumeLayout( false );
            this.grpTCExec.PerformLayout();
            this.panel1.ResumeLayout( false );
            this.panel1.PerformLayout();
            this.tabControl2.ResumeLayout( false );
            this.tabProcTxt.ResumeLayout( false );
            this.tabProcTxt.PerformLayout();
            this.tabProcFiles.ResumeLayout( false );
            this.tabControl1.ResumeLayout( false );
            this.tabRsltTxt.ResumeLayout( false );
            this.tabRsltTxt.PerformLayout();
            this.tabRsltFile.ResumeLayout( false );
            this.ResumeLayout( false );
            this.PerformLayout();

		}

		/// <summary>
		/// Der Haupteinstiegspunkt fr die Anwendung.
		/// </summary>
		[STAThread]
		static void Main( string[] args ) {

			if( args.Length < 1 ) {

				Application.Run(new frmTCExec());				
			}
			else {

				Application.Run(new frmTCExec( args[0] ));
			}
		}

		#endregion

		#region My Stuff

		// --------------------
		private void appCTCEx() {

			RsltXMLNode RTCExNode;

			string val;
			string dt;

			/*
				<!ELEMENT RefTCExec (EMPTY)>
					<!ATTLIST RefTCExec
						DateTime	NMTOKEN #REQUIRED
						ExCode		(er|ok) ""
						ExcDur		NMTOKEN #IMPLIED
						RefUID		NMTOKEN #REQUIRED
						UID				NMTOKEN #IMPLIED
					>
			*/

			RTCExNode = new RsltXMLNode( "RefTCExec" );

			RTCExNode.addUID(	m_uidRTCEx );

			if( RTCExNode.isOK() ) {

				dt = txtDate.Text + "T" + txtTime.Text;

				RTCExNode.addAttrib( "DateTime", dt );

				val = m_QNTools.getComboSelVal( ref comboExCode );
				RTCExNode.addAttrib( "ExCode", val );

				val = sWatch.getElapTimeStrMin1();
				RTCExNode.addAttrib( "ExcDur", val );

				RTCExNode.addAttrib( "RefUID", m_uidTCEx );

				m_xDB.appendSubTree( RTCExNode.m_xNode, m_uidCTC);	
			}				
		}

		//-------------------------------------------------------------------------					
		private void addLog( IRslt p_Res ) {

			int ix;

			string msg = BTools.getNowISOTime() + " " + p_Res.getRsltLastMsg();

			ix = comboLog.Items.Add( msg );

			m_Logger.write2Log( ref p_Res );

			comboLog.SelectedIndex = ix;
		}

		//-------------------------------------------------------------------------					
		private void addLog( string p_Msg ) {

			int ix;

			string msg = BTools.getNowISOTime() + " " + p_Msg;

			ix = comboLog.Items.Add( msg );

			m_Logger.write2Log( msg );

			comboLog.SelectedIndex = ix;
		}

		// --------------------------------
		private Rslt appResFile( ref string p_FileName ) {

			DateTime sDT;

			Ref2File r2f;

			Rslt res = new Rslt( true );

			string shortName;
			string fType;
			string dt;

			sDT = File.GetLastWriteTime( p_FileName );

			dt = BTools.getISODateTime( sDT );

			shortName = Path.GetFileName( p_FileName );

			fType = Path.GetExtension( p_FileName );
			
			r2f = new Ref2File( shortName, "", fType, dt, p_FileName );

			m_ResFilesLst.Add( r2f );

			lstResFiles.Items.Add( shortName );

			lstResFiles.Refresh();
	
			return res;
		}

		//-------------------------------------------------------------------------					
		private RsltXMLNode bldTCExDoc() {

			//int i, x;

			RsltString rVal;
			RsltXMLNode aNode;
			RsltXMLNode TCExNode;

			string excDur;
			string val;

			//string[] vals;

			/*
				<!ELEMENT TCExec ( TstSysRef, Comment?, RefProbRep*, ProcLog* )>
					<!ATTLIST TCExec
						Appl			CDATA #IMPLIED
						Cmpgn			CDATA #IMPLIED
						CmpgnUID	NMTOKEN #IMPLIED
						DateTime	NMTOKEN #REQUIRED
						ExCode		(er|ip|ok) ""
						Fctn			CDATA #IMPLIED
						Section		CDATA #IMPLIED
						SeqNum		CDATA	#IMPLIED
						SoftRel		NMTOKEN #REQUIRED
						ExcDur		NMTOKEN #IMPLIED
						Title			CDATA #REQUIRED
						TCUID			NMTOKEN #REQUIRED
						Author		CDATA	#REQUIRED
						UID				NMTOKEN #IMPLIED
					>
			*/

			string nodeName = "TCExec";
			TCExNode = new RsltXMLNode( nodeName );

			TCExNode.addUID( m_uidTCEx );

			TCExNode.createXmlDecl( "1.0", "", "" );

			if( TCExNode.isOK() ) {

				//<!DOCTYPE TestCase SYSTEM "RG.TestCaseV01.dtd">
				TCExNode.addSysDocTypeInfo( nodeName, QNDefs.dtdNameTCExe );
			}

			if( TCExNode.isOK() ) {

				//<!-- Generated by QA Navigator Test Case Executer V1.0.0.0-->
				string genCom = QNDefs.phrGenBy + m_QNTools.getApplInfo();
				TCExNode.addComment( genCom );
			}

			if( TCExNode.isOK() ) {

				//Appl
				TCExNode.addAttribAsHtml( "Appl", txtAppl.Text );

				//Cmpgn
				val = txtCmpgn.Text;

				TCExNode.addAttribAsHtml( "Cmpgn", val );

				TCExNode.addAttrib( "CmpgnUID", m_uidCmpgn );		

				//Date

				rVal = m_QNTools.chkVal( txtDate.Text, lblDate.Text );

				if( TCExNode.checkRslt( rVal ) ) {

					val = rVal.theString;

					rVal = m_QNTools.chkVal( txtTime.Text, lblTime.Text );

					if( TCExNode.checkRslt( rVal ) ) {

						val += "T" + rVal.theString;

						TCExNode.addAttrib( "DateTime", val );
					}				
				}
			}

			if( TCExNode.isOK() ) {

				//Excode
				val = m_QNTools.getComboSelVal( ref comboExCode );
				rVal = m_QNTools.chkVal( val, lblExCode.Text );

				if( TCExNode.checkRslt( rVal ) ) {

					TCExNode.addAttribAsHtml( "ExCode", rVal.theString );
				}
			}

			if( TCExNode.isOK() ) {

				//Fctn
				TCExNode.addAttribAsHtml( "Fctn", txtFctn.Text );

				//Section
				TCExNode.addAttribAsHtml( "Section", txtSection.Text );

				/* SeqNum not supported yet */

				//SoftRel
				val = m_QNTools.getComboSelVal( ref comboSoftRel );
				TCExNode.addAttribAsHtml( "SoftRel", val );

				excDur = sWatch.getElapTimeStrMin1();

				TCExNode.addAttrib( "ExcDur", excDur );

				TCExNode.addAttribAsHtml( "Title", txtTitle.Text );

				TCExNode.addAttrib( "TCUID", m_uidTC );

				TCExNode.addAttribAsHtml( "Author", txtAuthor.Text );
			}
			
			if( TCExNode.isOK() ) {

				/* <!ELEMENT TstSysRef (#PCDATA)>
						<!ATTLIST TstSysRef
							RefUID	NMTOKEN #IMPLIED
							Title		CDATA #IMPLIED
							UID			NMTOKEN #IMPLIED
						> */

				val = m_QNTools.getComboSelVal( ref comboTstSys );
	
				if( val.Length > 0 ) {

					aNode = TCExNode.appNode( "TstSysRef" );

					aNode.addUID( m_uidTstSys );

					aNode.addAttribAsHtml( "Title", val );

					//val = entry.val;
					//aNode.addAttrib( "RefUID", val );
				}
			}

			if( TCExNode.isOK() ) {

				aNode = TCExNode.appTxtNodeAsHTML( "Comment", txtComment.Text );

				if( aNode.isOK()) {

					aNode.addUID( m_uidComment );

				}
			}

			if( TCExNode.isOK() ) {

				m_ResFilesLst.loadYSUp( TCExNode );

				// no feed back from ProbRep yet, thus no ProbeRep list.

				/* 
					<!ELEMENT RefProbRep (EMPTY)>
						<!ATTLIST RefProbRep
							Title		CDATA #REQUIRED
							RefUID	NMTOKEN #REQUIRED
							UID			NMTOKEN #IMPLIED
						>
				*/

				/* 2008-02-06 required for resume testing?
				x = m_ProbRepLst.Count;

				for( i = 0; i < x; i++ ) {

					aNode = TCExNode.appNode( "RefProbRep" );

					if( aNode.notOK() ) {

						i = x;
					}
					else {

						vals = (string[])m_ProbRepLst[i];

						aNode.addAttrib( "RefUID", vals[0] );
						aNode.addAttribAsHtml( "Title", vals[1] );
						aNode.addAttrib( "UID", vals[2] );
					}
				}
				*/
			}

			return TCExNode;
		}

		// ---------------------------
		private void fileOKHdlr4ResFile(object sender, System.ComponentModel.CancelEventArgs e) {

			Rslt res;

			res = fileDialProc4OK(sender, e, new dlgtFileDialOK( appResFile ) );
		}

		//-----------------------------------
		private void doDialForAnyType( System.ComponentModel.CancelEventHandler p_openFileDial_FileOkHandler ) {
		
			try {

				setAppStat( AppStat.Proc );

				OpenFileDialog openFileDial;
				openFileDial = new OpenFileDialog();
				openFileDial.FileOk += p_openFileDial_FileOkHandler;

				openFileDial.Title = m_Presets.m_QNphrase.lblOpenTC;
				openFileDial.Filter = "All files (*.*)|*.*" ;
				openFileDial.FilterIndex = 1;
				//openFileDial.DefaultExt = "xml";
				
				//openFileDial.InitialDirectory = m_Presets.m_ExpPth;

				openFileDial.RestoreDirectory = true;
				
				DialogResult dRes = openFileDial.ShowDialog();

				if( DialogResult.Cancel == dRes ) {

					setAppStat( AppStat.OK );
				}

				openFileDial.Dispose();
			}
			catch( Exception excp ) {
						
				handleExcp( excp );
			}
		}		
		
		//-------------------------------------------------------------------------
		private Rslt fileDialProc4OK(object sender, System.ComponentModel.CancelEventArgs e, dlgtFileDialOK p_FuncHandleFile ) {

			Rslt res = new Rslt( false );

			try {

				string fileName;

				Cursor oldCur = Cursor.Current;

				Cursor.Current = Cursors.WaitCursor;

				OpenFileDialog dial = (OpenFileDialog)sender;

				fileName = dial.FileName;

				res = p_FuncHandleFile( ref fileName );

				Cursor.Current = oldCur;

				if( res.notOK() ) {

					string msg = String.Format( m_Presets.m_QNphrase.errLoadOfFailed, fileName );

					handleErr( res, msg );
				}
				else {

					setAppStat( AppStat.OK );

					addLog( String.Format( m_Presets.m_QNphrase.msgLoaded, txtTitle.Text ) );
				}
			}
			catch( Exception excp ) {
		
				handleExcp( excp );
			}          

			return res;
		}

		//-------------------------------------------------------------------------
		private void handleExcp( Exception p_Excp ) {
			
			try {

				setAppStat( AppStat.Error );

				addLog( "Exception '" + p_Excp.Message + "'");

				m_Logger.write2Log( ref p_Excp );

				m_GUIservice.dispExcp( p_Excp );
			}
			catch {

				string msg = "An exception has occured at a very early stage of the"
					+ " initialization of the program. So early that the program is not able"
					+ " to provide you any aid. Errors at this stage are mostly due to"
					+ " bad configuration. If the configuration has been changed recently,"
					+ " switch back to the former version, if you can. In other cases please"
					+ " refer to the list of known problems in your documentation.";

				MessageBox.Show(  msg, "Early Error Occured", MessageBoxButtons.OK, MessageBoxIcon.Error );
			}
		}

		//-------------------------------------------------------------------------
		private void handleErr( IRslt p_Res, string p_Msg ) {

			setAppStat( AppStat.Error );

			m_Logger.write2Log( ref p_Res );

			addLog( p_Msg );

			issueErr( p_Msg );
		}

		//-----------------------
		private void handleIfErr( IRslt p_Res, string p_Msg ) {

			if( p_Res.notOK() ) {

				handleErr( p_Res, p_Msg );
			}
		}

		//-------------------------------------------------------------------------
		private void issueErr( string msg ) {

			addLog( msg );

			MessageBox.Show( msg, m_QNphrase.lblErr, MessageBoxButtons.OK, MessageBoxIcon.Error );
		}

		//-------------------------------------------------------------------------
		private Rslt init() {

			frmTCExec.CheckForIllegalCrossThreadCalls = false;

			int ix, x, y;

			DatLstEntry entry;

			Rslt res = new Rslt( true );

			m_QNTools = new QNTools();

			m_QNphrase = m_QNTools.m_QNphrase;

			m_GUIservice = new QNGUIservice( m_QNphrase );

			m_ApplPth = m_QNTools.getApplPth();

			m_Presets = new QNpresets( m_QNTools );

			setClrs();

			// resizing stuff
			x = this.Width;
			y = this.Height;

			m_panel1DH = y - panel1.Height;

			m_butCloseDT = y - butClose.Top;
			m_butErrorDT = y - butError.Top;
			m_butNextDT = y - butNext.Top;
			m_butStartStopDT = y - butStartStop.Top;

			m_grpTCExecDT = y - grpTCExec.Top;

			m_txtStatDT = y - txtStat.Top;
			m_comboLogDT = y - comboLog.Top;

			m_Logger.write2Log( m_QNTools.getApplInfo() );

			setLabels();

			m_CTCSelPresets = new CTCSelPresets();
			m_TCSelPresets = new TCSelPresets();

			m_uidTC = "";
			m_uidCmpgn = "";

			m_TProcLst = new Ref2FileLst( "TestProcData" );
			m_TRefLst = new Ref2FileLst( "TestRsltData" );
			m_ResFilesLst = new Ref2FileLst( "TestRsltData" );

			//2008-02-06 required for resume testing?
			//m_ProbRepLst = new ArrayList();

			/*
			m_txtWin = new frmDebug();
			m_txtWin.Show();
			m_txtWin.Disposed += new System.EventHandler( debugWin_Disposed );
			*/
			
			m_SWIsStarted = false;
			sWatch = new StopWatch( 60000 );
			sWatch.Elapsed += new ElapsedEventHandler(OnTick);

			//test ???
			//sWatch.setup( 33000000 );

			if( res.checkRslt( m_Presets ) ) {

				m_CTCSelPresets.m_Assgn = m_Presets.m_Author;

				// reduce campaign state selection to "in exec"
				m_CmpgnStatLst = new DataLst(1);

				ix = m_Presets.m_CmpgnStatLst.getIdxByVal( "ex" );

				entry = m_Presets.m_CmpgnStatLst[ix];

				m_CmpgnStatLst.Add( entry );

				m_CmpSelPresets = new CmpSelPresets( "" );
			}

			if( res.isOK() ) {
				
				// I think this UID business is obsolete.
				// due to the changed design on does not need to pre-allocate UIDs anymore
				// dump it and see if it still works.
				// or check the Java TCEx report builder.

				RsltString rUID = m_Presets.m_UIDSrvClient.getUID();			

				if( rUID.notOK() ){

					m_uidTCEx = "";
					m_uidRTCEx = "";

					res.setRsltStat( rUID, m_QNphrase.errUID );
				}
				else {

					m_uidTCEx = rUID.theString;

					rUID = m_Presets.m_UIDSrvClient.getUID();
					m_uidRTCEx = rUID.theString;
				}
			}

			if( res.isOK() ) {

				setUpAppl();

                m_DB = new RGSQL2( m_Presets.m_DBloc, m_Presets.m_DBname, m_Presets.m_DBuser, m_Presets.m_DBpw );

				if( res.checkRslt( m_DB ) ) {

    				m_xDB = new XMLDB( m_DB, m_Presets.m_UIDsrvLoc );

					res.setRsltStat( m_xDB, m_QNphrase.errDBconn );
				}
			}

			if( res.notOK() ) {

				handleErr( res, m_QNphrase.errInitFailed );
			}
			else {

				resetTC();

				resetTCExe();

				setAppStat( AppStat.OK );
				
				addLog( BTools.getNowISODate() + " " + m_QNphrase.msgSesStart );
			}

			setApplEnabled( false );
			
			/*
			m_ImgLstHBeat = new Image[14];

			m_ImgLstHBeat[0] = Image.FromFile("HBeat0.bmp");
			m_ImgLstHBeat[1] = Image.FromFile("HBeat1.bmp");
			m_ImgLstHBeat[2] = Image.FromFile("HBeat2.bmp");
			m_ImgLstHBeat[3] = Image.FromFile("HBeat3.bmp");
			m_ImgLstHBeat[4] = Image.FromFile("HBeat4.bmp");
			m_ImgLstHBeat[5] = Image.FromFile("HBeat5.bmp");
			m_ImgLstHBeat[6] = Image.FromFile("HBeat6.bmp");
			m_ImgLstHBeat[7] = Image.FromFile("HBeat7.bmp");
			m_ImgLstHBeat[8] = Image.FromFile("HBeat8.bmp");
			m_ImgLstHBeat[9] = Image.FromFile("HBeat8.bmp");
			m_ImgLstHBeat[10] = Image.FromFile("HBeat7.bmp");
			m_ImgLstHBeat[11] = Image.FromFile("HBeat5.bmp");
			m_ImgLstHBeat[12] = Image.FromFile("HBeat3.bmp");
			m_ImgLstHBeat[13] = Image.FromFile("HBeat1.bmp");

			*/
			m_HBeatIx = -1;

			//pnlHBeat.BackgroundImage = m_ImgLstHBeat[0];


			return res;
		}

		//-------------------------------------------------------------------------
		private Rslt loadTC( XmlDocument p_XDoc ) {

			Rslt res;
			RsltString aVal;
			RsltString xVal;
			RsltXMLNode xNode;
			RsltXMLNode aNode;

			XmlNodeList nodeLst;

			/*
				<!ELEMENT TestCase ( Desc, RefTC+, ReqmntSrc+, TSysConfigRef, TestProc, ExpResult, ExpDur )>
					<!ATTLIST TestCase
						Appl			CDATA #IMPLIED
						Author		CDATA #REQUIRED
						Date			NMTOKEN #REQUIRED
						Fctn			CDATA #IMPLIED
						Section		CDATA #IMPLIED
						SoftRel		CDATA #IMPLIED
						TCType		(ac|co|do|fi|fu|io|lo|mo|pe|se|un|us|vo|aid|prep) ""
						Time			NMTOKEN #REQUIRED
						Title			CDATA #REQUIRED
						UID				NMTOKEN #IMPLIED
						Ver				NMTOKEN #REQUIRED
						Prio			NMTOKEN #IMPLIED
					>
			*/

			res = new Rslt( true );

			nodeLst = p_XDoc.SelectNodes( "/TestCase" );

			if( 1 != nodeLst.Count ) {

				res.setInError( m_QNphrase.errInvXML );
			}
			else {

				xNode = nodeLst.Item( 0 );

				m_uidTC = xNode.UID;

				xVal = xNode.getAttrValFromHtml( "Appl" );

				txtAppl.Text = xVal.theString;

				//xVal = xNode.getAttrVal( "Date" );

				//wrong field: txtDate.Text = xVal.theString;

				xVal = xNode.getAttrValFromHtml( "Fctn" );
	  
				txtFctn.Text = xVal.theString;

				aVal = xNode.getAttrValFromHtml( "Prio" );

				xVal = m_Presets.m_TstPrioLst.getLabelByVal( aVal.theString );
	  
				txtTCPrio.Text = xVal.theString;

				xVal = xNode.getAttrValFromHtml( "Section" );

				txtSection.Text = xVal.theString;

				xVal = xNode.getAttrValFromHtml( "SoftRel" );

				txtTCSoftRel.Text = xVal.theString;

				aVal = xNode.getAttrValFromHtml( "TCType" );

				xVal = m_Presets.m_TstTypeLst.getLabelByVal( aVal.theString );

				txtTCType.Text = xVal.theString;
				
				// Title
				xVal = xNode.getAttrValFromHtml( "Title" );

				txtTitle.Text = xVal.theString;

				xVal = xNode.getAttrValFromHtml( "Ver" );

				txtTCVer.Text = xVal.theString;

				/*	<!ELEMENT TSysConfigRef (EMPTY)>
							<!ATTLIST TSysConfigRef
								RefUID	NMTOKEN #IMPLIED
								Title		CDATA #IMPLIED
								UID			NMTOKEN #IMPLIED
							> */

				nodeLst = xNode.m_xNode.SelectNodes( "./TSysConfigRef" );

				if( nodeLst.Count == 1 ) {

					aNode = nodeLst.Item( 0 );

					xVal = aNode.getAttrValFromHtml( "Title" );

					txtTSysConfig.Text = xVal.theString;
				}

				/*	Desc, TestProc, ExpResult */
				aNode = xNode.getSubNode( "Desc" );

				if( res.checkRslt( aNode ) ) {

					txtDesc.Text = aNode.textFromHtml;
				}

				aNode = xNode.getSubNode( "TestProc" );

				if( res.checkRslt( aNode ) ) {

					txtTstProc.Text = aNode.textFromHtml;
				}

				m_TProcLst.loadYSDown( xNode, lstTstProcFile );

				if( res.checkRslt( m_TProcLst ) ) {

					aNode = xNode.getSubNode( "ExpResult" );
					
					if( res.checkRslt( aNode ) ) {

						txtExpRslt.Text = aNode.textFromHtml;
					}
				}

				m_TRefLst.loadYSDown( xNode, lstTstRefFile );

				res.checkRslt( m_TRefLst );
			}

			return res;
		}

		//------------------------
		private void loadTCEx( ref string p_UID ) {

			XMLDBNode xDBNode; 

			Rslt res = new Rslt( true );

			xDBNode = m_xDB.getXMLsubTree( ref p_UID );

			if( res.checkRslt( xDBNode )  ) {

				res = loadTCExe( xDBNode.m_xDoc );
			}

			if( res.notOK() ) {

				m_Logger.write2Log( "Loading of '" +  p_UID + "' failed." );

				string msg =  m_QNphrase.errLoadFailed;
				handleErr( res, msg );
			}
		}

		//-------------------------
		private Rslt loadTCExe( XmlDocument p_XDoc ) {

			Rslt res;
			RsltString xVal;
			RsltXMLNode xNode;
			RsltXMLNode aNode;

			string val;

			XMLDBNode xDBNode;

			XmlNodeList nodeLst;

			/*
				<!ELEMENT TCExec ( TstSysRef, Comment?, RefProbRep*, ProcLog* ) >
					<!ATTLIST TCExec
						Appl			CDATA #IMPLIED
						Cmpgn			CDATA #IMPLIED
						CmpgnUID	NMTOKEN #IMPLIED
						DateTime	NMTOKEN #REQUIRED
						ExCode		(er|ip|ok) ""
						Fctn			CDATA #IMPLIED
						Section		CDATA #IMPLIED
						SeqNum		CDATA	#IMPLIED
						SoftRel		NMTOKEN #REQUIRED
						ExcDur		NMTOKEN #IMPLIED
						Title		  CDATA #REQUIRED
						TCUID			NMTOKEN #REQUIRED
						Author		CDATA	#REQUIRED
						UID				NMTOKEN #IMPLIED
					>
			*/

			res = new Rslt( true );

			nodeLst = p_XDoc.SelectNodes( "/TCExec" );

			if( 1 != nodeLst.Count ) {

				m_Logger.write2Log( "Top node 'TCExec' not found." );

				res.setInError( m_QNphrase.errInvXML );
			}
			else {

				xNode = nodeLst.Item( 0 );
			
				if( res.checkRslt( xNode ) ) {
					
					#region TCEx Attrib

					m_uidTCEx = xNode.UID;

					xVal = xNode.getAttrVal( "Cmpgn" );
					txtCmpgn.Text = xVal.theString;
					
					xVal = xNode.getAttrVal( "CmpgnUID" );
					m_uidCmpgn = xVal.theString;

					xVal = xNode.getAttrVal( "DateTime" );

					if( res.checkRslt( xVal ) ) {

						val = BTools.getDateFromISODateTime( xVal.theString );   
						txtDate.Text = val;

						val = BTools.getTimeFromISODateTime( xVal.theString );   
						txtTime.Text = val;
					}
				}

				if( res.checkRslt( xNode ) ) {

					xVal = xNode.getAttrVal( "ExCode" );
					m_QNTools.selByDataLstVal( ref comboExCode, xVal.theString );

					/* not supported yet
					xVal = xNode.getAttrVal( "SeqNum" );
					*/

					xVal = xNode.getAttrVal( "SoftRel" );
					m_QNTools.selByDataLstVal( ref comboSoftRel, xVal.theString );

					xVal = xNode.getAttrVal( "ExcDur" );
					txtElapTime.Text = xVal.theString;

					xVal = xNode.getAttrVal( "TCUID" );
					m_uidTC = xVal.theString;

					xVal = xNode.getAttrVal( "Author" );
					txtAuthor.Text = xVal.theString;

					#endregion
				}

				if( res.isOK() ) {

					/*
						<!ELEMENT TstSysRef (EMPTY)>
							<!ATTLIST TstSysRef
								RefUID	NMTOKEN #IMPLIED
								Title		CDATA #IMPLIED
								UID			NMTOKEN #IMPLIED
							>
					*/

					aNode = xNode.getSubNode( "TstSysRef" );

					//2008-02-05 if( res.checkRslt( aNode ) ) {
					if( aNode.isOK() ) {

						xVal = aNode.getAttrValFromHtml( "Title" );

						m_QNTools.selByDataLstVal( ref comboTstSys, xVal.theString );

						xVal = aNode.getAttrVal( "RefUID" );
						m_uidRefTstSys = xVal.theString;

						m_uidTstSys = aNode.UID;
					}
				}

				if( res.isOK() ) {

					aNode = xNode.getSubNode( "Comment" );

					//2008-02-05 if( res.checkRslt( aNode ) ) {
					if( aNode.isOK() ) {

						txtComment.Text = aNode.textFromHtml;
						m_uidComment = aNode.UID;
					}
				}
			}

			if( res.isOK() ) {

				xDBNode = m_xDB.getXMLsubTree( ref m_uidTC );

				if( res.checkRslt( xDBNode ) ) {	
					
					res = loadTC( xDBNode.m_xDoc );
				}
			}		

			//RefProbRep*, ProcLog* 

			return res;
		}

		//-------------------------------------------------------------------------
		private void loadTCloader() {

			Rslt res = new Rslt();

			XMLDBNode xDBNode;

			try {

				resetTC();

				xDBNode = m_xDB.getXMLsubTree( ref m_loadUID );

				res.setRsltStat( xDBNode );

				if( res.isOK() ) {

					reset4Load();

					res = loadTC( xDBNode.m_xDoc );

					if( res.notOK() ) {

						res.addRsltAddInfo( "Failed to load TC." );
					}
					else {
				
						menuEditTC.Enabled = true;
						menuRelTC.Enabled = true;
						menuPrint.Enabled = true;
					}
				}

				if( res.notOK() ) {

					string msg =  m_QNphrase.errLoadFailed;
					handleErr( res, msg );
				}
				else {

					setAppStat( AppStat.OK );

					setApplEnabled( true );

					addLog( String.Format( m_QNphrase.msgLoaded, txtTitle.Text ) );
				}
			}
			catch( Exception e ) {
		
				handleExcp( e );
			}
		}

		//-------------------------------------------------------------------------
		private void resetTC() {

			txtAppl.Text = "";
			txtDesc.Text = "";
			txtFctn.Text = "";
			txtExpRslt.Text = "";
			txtSection.Text = "";
			txtTCPrio.Text = "";
			txtTCSoftRel.Text = "";
			txtTCType.Text = "";
			txtTCVer.Text = "";
			txtTitle.Text = "";
			txtTSysConfig.Text = "";
			txtTstProc.Text = "";

			m_TProcLst.Clear();
			lstTstProcFile.Items.Clear();

			m_TRefLst.Clear();
			lstTstRefFile.Items.Clear();
		}

		//-------------------------------------------------------------------------
		private void resetTCExe() {

			m_uidCTC = "";
			
			txtComment.Text = "";

			// '2008-02-06 required for resume testing? m_ProbRepLst.Clear();

			comboExCode.SelectedIndex = 0;

			txtDate.Text = BTools.getNowISODate();
			txtTime.Text = BTools.getNowISOTime();

			m_QNTools.reFillUpCombo( ref comboExCode, ref m_Presets.m_TstExCodeLst, 0 );
			//setUpAppl();

			sWatch.reset();

			m_SWIsStarted = false;
			butStartStop.Text = m_QNphrase.blblStart;

			DateTime eTime = sWatch.elapTime;

			txtElapTime.Text = BTools.getISOTime( eTime );

			m_ResFilesLst.Clear();
			lstResFiles.Items.Clear();
		}

		//---------------------------
		private void reset2New() {

			// UID get prepared at load of a new TC
			// prepUIDs();

			setAppStat( AppStat.Proc );

			resetTC();

			resetTCExe();

			setApplEnabled( false );

			setAppStat( AppStat.OK );
		}

		//----------------------------
		// Called from within the TCloader
		private Rslt reset4Load() {

			Rslt res = prepUIDs();

			comboExCode.SelectedIndex = 0;

			if( res.notOK() ) {

				res.addRsltAddInfo( "'reset4Load()' failed." );
			}

			return res;
		}

		//-----------------------------
		private Rslt prepUIDs() {

			Rslt res = new Rslt( RsltStatVal.isOK );
			RsltString rUID;

			// I think this UID business is obsolete.
			// due to the changed design on does not need to pre-allocate UIDs anymore
			// dump it and see if it still works.
			// or check the Java TCEx report builder.

			rUID = m_Presets.m_UIDSrvClient.getUID();

			if( rUID.notOK() ){

				m_uidTCEx = "";
				m_uidRTCEx = "";

				res.setRsltStat( rUID, m_QNphrase.errUID );
			}
			else {

				m_uidTCEx = rUID.theString;
				
				rUID = m_Presets.m_UIDSrvClient.getUID();
				m_uidRTCEx = rUID.theString;
			}

			m_uidRefTstSys = "";
			m_uidTstSys = "";
			m_uidComment = "";

			if( res.notOK() ) {

				res.addRsltAddInfo( "'prepUIDs()' failed." );
			}

			return res;
		}

		//-----------------------------------------------------
		private Rslt saveTCEx() {

			Rslt res = new Rslt( RsltStatVal.isOK );
			string msg = "";

			string title = txtCmpgn.Text + ": " + txtTitle.Text;
				
			RsltXMLNode xNode;

			xNode = bldTCExDoc();

			if( xNode.notOK() ) {

				res.setRsltStat( xNode );

				msg = String.Format( m_QNphrase.errCrtngFailed, title );
			}
			else {

				m_xDB.importXML( ref xNode.m_xDoc );

				//xNode.m_xDoc.Save( "TCexTst.xml" );

				if( m_uidCTC.Length > 0 ) {

					appCTCEx();
				}
			}

			if( res.isOK() ) {

				setAppStat( AppStat.OK );

				addLog( String.Format( m_QNphrase.msgSaved, title ) );
			}
			else {
			
				handleErr( res, msg );
			}

			return res;
		}

		//-----------------------------------------------------
		private void setApplEnabled( bool p_Enabled ) {

			butError.Enabled = p_Enabled;
			butClose.Enabled = p_Enabled;
			butNext.Enabled = p_Enabled;
			butStartStop.Enabled = p_Enabled;

			ctxtResFileAdd.Enabled = p_Enabled;

			menuCancel.Enabled = p_Enabled;
			menuEditTC.Enabled = p_Enabled;
			menuPrint.Enabled = p_Enabled;
			menuRelTC.Enabled = p_Enabled;
		}
		
		//-----------------------------------------------------
		private void selCmpgn() {
		
			try {

				DataLst RsltLst;

				int x;
				DatLstEntry entry;

				RsltString softRel;
			
				setAppStat( AppStat.Proc );

				frmCmpSel dialCmpSel = new frmCmpSel( m_xDB, true, m_Presets, m_CmpgnStatLst, m_CmpSelPresets );

				DialogResult dRes = dialCmpSel.ShowDialog();

				if( DialogResult.Cancel != dRes ) {

					RsltLst = dialCmpSel.m_RsltLst;

					x = RsltLst.Count;

					if( x > 0 ) {

						reset2New();

						entry = RsltLst[0];

						txtCmpgn.Text = entry.label;
						m_uidCmpgn = entry.val;

						softRel = m_xDB.getAttrVal( m_uidCmpgn, "SoftRel" );

						if( softRel.isOK() ) {

							m_QNTools.selByDataLstVal( ref comboSoftRel, softRel.theString );
						}
					}
				}

				setAppStat( AppStat.OK );

				dialCmpSel.Dispose();
			}
			catch( Exception excp ) {
		
				handleExcp( excp );
			}
		}

		//-----------------------------------------------------
		private void setAppStat( AppStat p_Stat ) {

			switch( p_Stat) {

				case AppStat.OK:

					txtStat.BackColor = m_Presets.m_ClrStatOK;
					txtStat.ForeColor = Color.White;
					txtStat.Text = m_QNphrase.lblOK;
					break;

				case AppStat.Proc:

					txtStat.BackColor = m_Presets.m_ClrStatProc;
					txtStat.ForeColor = Color.Black;
					txtStat.Text = m_QNphrase.lblProcng;
				break;

				case AppStat.Error:

					txtStat.BackColor = m_Presets.m_ClrStatErr;
					txtStat.ForeColor = Color.White;
					txtStat.Text =  m_QNphrase.lblErr;
				break;
			}
		}

		//--------------------------
		private void setClrs() {

			this.BackColor = m_Presets.m_ClrPnlBck;
			this.ForeColor = m_Presets.m_ClrPnlFor;
						
			butClose.BackColor = m_Presets.m_ClrButBck;
			butClose.ForeColor = m_Presets.m_ClrPnlFor;

			butError.BackColor = m_Presets.m_ClrButBck;
			butError.ForeColor = m_Presets.m_ClrPnlFor;

			butNext.BackColor = m_Presets.m_ClrButBck;
			butNext.ForeColor = m_Presets.m_ClrPnlFor;

			butStartStop.BackColor = m_Presets.m_ClrButBck;
			butStartStop.ForeColor = m_Presets.m_ClrPnlFor;

			comboLog.BackColor = m_Presets.m_ClrTxtBck;

			comboExCode.BackColor = m_Presets.m_ClrTxtBck;
			comboSoftRel.BackColor = m_Presets.m_ClrTxtBck;
			comboTstSys.BackColor = m_Presets.m_ClrTxtBck;

			lstResFiles.BackColor = m_Presets.m_ClrTxtBck;

			txtAuthor.BackColor = m_Presets.m_ClrTxtBck;
			txtCmpgn.BackColor = m_Presets.m_ClrTxtBck;
			txtComment.BackColor = m_Presets.m_ClrTxtBck;
			txtElapTime.BackColor = m_Presets.m_ClrTxtBck;
			txtDate.BackColor = m_Presets.m_ClrTxtBck;
			txtTime.BackColor = m_Presets.m_ClrTxtBck;
		}

		// ----------------------------------------------------
		private void setUpAppl() {
		
			txtAuthor.Text = m_Presets.m_Author;

			m_QNTools.reFillUpCombo( ref comboSoftRel, ref m_Presets.m_TstSoftRelLst, 0);

			m_QNTools.reFillUpCombo( ref comboTstSys, ref m_Presets.m_TstSysLst, 0);

			m_QNTools.reFillUpCombo( ref comboExCode, ref m_Presets.m_TstExCodeLst, 0);
		}

		// ----------------------------------------------------
		private void stop_Watch( bool p_Cont ) {

			DateTime eTime;

			sWatch.Stop();

			if( p_Cont ) {

				butStartStop.Text = m_QNphrase.blblCont;
			}
			else {

				butStartStop.Text = m_QNphrase.blblStart;
			}

			m_SWIsStarted = false;

			eTime = sWatch.elapTime;
			this.txtElapTime.Text = BTools.getISOTime( eTime );

			tmrHBeat.Stop();
			butHBeat.ImageIndex = 0;
			//pnlHBeat.BackgroundImage = m_ImgLstHBeat[0];
		}

		#endregion

		//---------------------------------------------------------
		// ?????????????
		/*
		private void debugWin_Disposed(object sender, System.EventArgs e) {

			m_txtWin = null;
		}
		*/

		#region event handling

		// ----------------------------------------------------
		private void butStartStop_Click(object sender, System.EventArgs e) {

			if ( m_SWIsStarted ) {

				stop_Watch( true );
			}
			else {

				sWatch.Start();
				butStartStop.Text = m_QNphrase.blblStop;
				m_SWIsStarted = true;

				m_HBeatIx = -1;
				tmrHBeat.Start();
			}		
		}

		// ------------------------------------------------------------------------
		private void menuExeTC_Click(object sender, System.EventArgs e) {
		
			try {
		
				setAppStat( AppStat.Proc );

				if( txtCmpgn.Text.Length > 0 ) {

					frmCTCSel dialCTCSel = new frmCTCSel(	m_xDB, m_uidCmpgn, m_CTCSelPresets, m_Presets );

					handleSelDial( ref dialCTCSel );
				}
				else {

					frmTCSel dialTCSel = new frmTCSel( m_xDB, true, m_Presets, m_TCSelPresets, "tc" );

					handleSelDial( ref dialTCSel );
				}
			}
			catch( Exception excp ) {
		
				handleExcp( excp );
			}		
		}

		// ------------------------------------------------------------------------
		private void menuExit_Click(object sender, System.EventArgs e) {
		
			setAppStat( AppStat.Proc );

			Close();
		}

		// ------------------------------------------------------------------------		
		private void OnTick( object sender,	ElapsedEventArgs e	) {

			DateTime eTime;

			eTime = ((StopWatch)sender).elapTime;
			//test
			txtElapTime.Text = BTools.getISOTime( eTime );
		}

		// ----------------------------------------------------
		private void butClose_Click(object sender, System.EventArgs e) {

			Rslt res;

			setAppStat( AppStat.Proc );

			stop_Watch( false );

			setAppStat( AppStat.Proc );
				
			res = saveTCEx();

			if( res.isOK() ) {

				reset2New();

				setAppStat( AppStat.OK );
			}
			else {

				handleErr( res, m_QNphrase.errTCExSaveFailed );
				butClose.Enabled = true;
			}
		}

		// ----------------------------------------------------
		private void ctxtLogEntry_Click(object sender, System.EventArgs e) {
		
			string msg;

			setAppStat( AppStat.Proc );

			msg = m_QNTools.getComboSelVal( ref comboLog );

			MessageBox.Show( msg, m_QNphrase.lblLogEntry, MessageBoxButtons.OK );
	
			setAppStat( AppStat.OK );
		}

		// ----------------------------------------------------
		private void butNext_Click(object sender, System.EventArgs e) {
		
			try {

				Rslt res = new Rslt( RsltStatVal.isOK );

				setAppStat( AppStat.Proc );

				if( m_SWIsStarted ) {

					stop_Watch( false );

					res = saveTCEx();
				}

				if( res.isOK() ) {

					reset2New();
					
					frmTCSel dialTCSel = new frmTCSel( m_xDB, m_uidTC, m_Presets );

					handleSelDial( ref dialTCSel );
				}
			}
			catch( Exception excp ) {
		
				handleExcp( excp );
			}	
		}

		// ----------------------------------------------------
		void handleSelDial( ref frmCTCSel p_dialCTCSel ) {

			CTCdata dat;

			int x;

			RsltLst RsltLst;

			DialogResult dRes = p_dialCTCSel.ShowDialog();

			if( DialogResult.Cancel == dRes ) {

				setAppStat( AppStat.OK );
			}
			else {

				RsltLst = p_dialCTCSel.m_RsltLst;

				x = RsltLst.Count;

				if( x > 0 ) {

					resetTCExe();

					dat = (CTCdata)RsltLst[0];

					m_uidCTC = dat.m_UID;

					m_loadUID = dat.m_RefUID;

					Thread loadThread = new Thread(new ThreadStart(loadTCloader));

					loadThread.Start();
				}
			}

			p_dialCTCSel.Dispose();
		}

		// ----------------------------------------------------
		void handleSelDial( ref frmTCSel p_dialTCSel ) {

			DatLstEntry entry;
			DataLst RsltLst;
			int x;

			DialogResult dRes = p_dialTCSel.ShowDialog();

			if( DialogResult.Cancel == dRes ) {

				setAppStat( AppStat.OK );
			}
			else {

				RsltLst = p_dialTCSel.m_RsltLst;

				x = RsltLst.Count;

				if( x > 0 ) {

					entry = RsltLst[0];
					/*
						m_txtWin = new frmDebug();
						m_txtWin.Text = m_QNphrase.lblException;
					*/
					m_loadUID = entry.val;

					resetTCExe();

					Thread loadThread = new Thread(new ThreadStart(loadTCloader));

					// Start the thread.
					loadThread.Start();
				}
			}

			p_dialTCSel.Dispose();
		}

		// -----------------------------
		/// <summary>
		/// Displays a text dialog. Detects, if the dialog is supposed to allow editing.
		/// If so, the Rslt is written back to p_Sender. 
		/// </summary>
		/// <param name="p_Sender"></param>
		/// <param name="p_Title"></param>
		private void handleTxtPop( object p_Sender, string p_Title ) {

			try {

				bool forEdit;
				DialogResult dRes;
				TextBox tBox;

				tBox = (TextBox)p_Sender;
				
				forEdit = !(tBox.ReadOnly);
			
				setAppStat( AppStat.Proc );

				frmTxtWin txtWin;
		
				txtWin = new frmTxtWin( forEdit, ref m_Presets );

				txtWin.Text = p_Title;

				txtWin.setText( tBox.Text );

				txtWin.TopMost = true;

				dRes = txtWin.ShowDialog();

				if( DialogResult.OK == dRes ) {

					if( forEdit ) {

						tBox.Text = txtWin.m_Text;
					}

					setAppStat( AppStat.OK );
				}

				txtWin.Dispose();

				setAppStat( AppStat.OK );
			}
			catch( Exception excp ) {
				
				handleExcp( excp );
			}	
		}

		// ----------------------------------------------------
		private void butError_Click(object sender, System.EventArgs e) {
		
			try {

				String arg;

				setAppStat( AppStat.Proc );

				stop_Watch( true );

				comboExCode.SelectedIndex = 1;

				saveTCEx();

				System.Diagnostics.Process proc = new System.Diagnostics.Process();

				proc.EnableRaisingEvents = false;
				
//m_Logger.write2Log( m_Presets.m_WebExp );

				proc.StartInfo.FileName = m_Presets.m_WebExp;

				/* "http://localhost:8080/piQa/index.jsp?QNA=ProbRep&ErrType=Test&Appl=TC+Editor
				 * &SoftRel=1.0&Fctn=New&TCtitle=Error+Test&TCExUID=123456789012300
				 * &TCExTitle=Test+the+Tester&Author=RDG" */

				arg = "index.jsp?QNA=RepProb&ProbType=Test&Appl=";

				arg += SFormatter.encodeURL( txtAppl.Text );
				arg += "&TCExUID=";
				arg += m_uidTCEx;

				arg += "&SoftRel=";
				arg += SFormatter.encodeURL( m_QNTools.getComboSelVal( ref comboSoftRel ) );

				arg += "&ExSys=";
				arg += SFormatter.encodeURL( m_QNTools.getComboSelVal( ref comboTstSys ) );

				/* superfluos ?
				arg += "&CmpgnUID=";
				arg += m_uidCmpgn;

				arg += "&TCUID=";
				arg += m_uidTC;*/

				/* we use the campaign
				arg += "&TCExTitle=";

				if( txtCmpgn.Text.Length > 0 ) {

					arg += SFormatter.encodeURL( txtCmpgn.Text  + ":" );
				}

		 		arg += SFormatter.encodeURL( txtTitle.Text );

				arg += "&Fctn=";
				arg += SFormatter.encodeURL( txtFctn.Text );

				arg += "&TCtitle=";
				arg += SFormatter.encodeURL( txtTitle.Text ); 
				*/

				//arg += "&Author=";
				//arg += txtAuthor.Text;

				arg = m_Presets.m_WebExpPrm + "\"" +  m_Presets.m_QNWebPth + arg + "\"";

//m_Logger.write2Log( arg );

				proc.StartInfo.Arguments = arg;
				proc.Start();
			}
			catch( Exception excp ) {
						
				handleExcp( excp );
			}	
		}

		// -----------------------------------
		private void txtComment_DoubleClick(object sender, System.EventArgs e) {
		
			handleTxtPop( sender, lblComment.Text );
		}

		// -----------------------------------
		private void txtDesc_DoubleClick(object sender, System.EventArgs e) {
		
			handleTxtPop( sender, lblDesc.Text );
		}

		// -----------------------------------
		private void txtTstProc_DoubleClick(object sender, System.EventArgs e) {
		
			handleTxtPop( sender, tabProcTxt.Text );
		}

		// -----------------------------------
		private void txtExpRslt_DoubleClick(object sender, System.EventArgs e) {
		
			handleTxtPop( sender, tabRsltTxt.Text );
		}
		
		// -----------------------------------
		private void menuEditTC_Click(object sender, System.EventArgs e) {
		
			try {

				stop_Watch( true );

				setAppStat( AppStat.Proc );

				System.Diagnostics.Process proc = new System.Diagnostics.Process();

				proc.EnableRaisingEvents = false;

				proc.StartInfo.FileName = QNDefs.exeTCEdit;

				proc.StartInfo.Arguments = m_uidTC;
				proc.Start();

				setAppStat( AppStat.OK );
			}
			catch( Exception excp ) {

				handleExcp( excp );
			}
		}

		// -----------------------------------
		private void menuRelTC_Click(object sender, System.EventArgs e) {
			
			setAppStat( AppStat.Proc );
			
			stop_Watch( true );

			Thread loadThread = new Thread(new ThreadStart(loadTCloader));
			loadThread.Start();
		}

		// -----------------------------------
		private void menuCancel_Click(object sender, System.EventArgs e) {

			reset2New();
		}

		// -----------------------------------
		private void menuDocu_Click(object sender, System.EventArgs e) {

			try {

				setAppStat( AppStat.Proc );

				System.Diagnostics.Process proc = new System.Diagnostics.Process();

				proc.EnableRaisingEvents = false;

				proc.StartInfo.FileName = QNDefs.manQN;

				proc.Start();

				setAppStat( AppStat.OK );
			}
			catch( Exception excp ) {
	
				handleExcp( excp );
			}
		}

		// --------------------
		private void menuAbout_Click(object sender, System.EventArgs e) {
		
			string title;
			string msg;

			setAppStat( AppStat.Proc );

			title = String.Format( m_QNphrase.msgAbout, m_QNphrase.lblTCExer );

			msg = m_QNTools.getAboutInfoBlock();
			
			MessageBox.Show( msg, title, MessageBoxButtons.OK );

			setAppStat( AppStat.OK );
		}

		// --------------------
		private void ctxtCmgnSel_Click(object sender, System.EventArgs e) {
		
			selCmpgn();
		}

		// --------------------
		private void ctxtCmpgnClear_Click(object sender, System.EventArgs e) {
		
			reset2New();

			txtCmpgn.Text = "";
			m_uidCmpgn = "";
		}

		//-------------------------
		private void butStartStop_MouseEnter(object sender, System.EventArgs e) {
		
			butStartStop.BackColor = m_Presets.m_ClrButHigh;
		}

		//-------------------------
		private void butStartStop_MouseLeave(object sender, System.EventArgs e) {
		
			butStartStop.BackColor = m_Presets.m_ClrButBck;
		}

		//-------------------------
		private void butError_MouseEnter(object sender, System.EventArgs e) {
		
			butError.BackColor = m_Presets.m_ClrButHigh;
		}

		//-------------------------
		private void butError_MouseLeave(object sender, System.EventArgs e) {
		
			butError.BackColor = m_Presets.m_ClrButBck;
		}

		//-------------------------
		private void butClose_MouseEnter(object sender, System.EventArgs e) {
		
			butClose.BackColor = m_Presets.m_ClrButHigh;
		}

		//-------------------------
		private void butClose_MouseLeave(object sender, System.EventArgs e) {
		
			butClose.BackColor = m_Presets.m_ClrButBck;
		}

		//-------------------------
		private void butNext_MouseEnter(object sender, System.EventArgs e) {
		
			butNext.BackColor = m_Presets.m_ClrButHigh;
		}

		//-------------------------
		private void butNext_MouseLeave(object sender, System.EventArgs e) {
		
			butNext.BackColor = m_Presets.m_ClrButBck;
		}
				
		//-------------------------
		private void tmrHBeat_Tick(object sender, System.EventArgs e) {
		
			if( m_HBeatIx > 12 ) {

				m_HBeatIx = 0;
			}
			else {

				m_HBeatIx++;
			}
			
			butHBeat.ImageIndex = m_HBeatIx;
			//pnlHBeat.BackgroundImage = m_ImgLstHBeat[m_HBeatIx];
		}

		//-------------------------
		private void menuPrint_Click(object sender, System.EventArgs e) {
		
			string title;

			Rslt res = new Rslt( true );

			setAppStat( AppStat.Proc );

			RsltXMLNode xNode = bldTCExDoc();

			string xsltName = QNDefs.xlsTCExec + "_" + m_QNphrase.m_Loc + ".xsl";

			if( res.checkRslt( xNode ) ) {

				title = m_QNphrase.lblTCExec + " '" + txtTitle.Text + "'";

				res = m_GUIservice.printXDoc( xNode.m_xDoc, ref xsltName, ref title );
			}

			if( res.notOK() ) {

				handleErr( res, m_Presets.m_QNphrase.errPrintFailed );
			}
			else {

				setAppStat( AppStat.OK );
			}
		}
		
		// ------------------------------
		private void menuSelCmpgn_Click(object sender, System.EventArgs e) {
		
			selCmpgn();
		}
		
		// ------------------------------
		private void frmTCExec_Resize(object sender, System.EventArgs e) {
		
			int x, y;

			y = this.Height;
			x = this.Width;

			panel1.Height = y - m_panel1DH;

			grpTCExec.Top = y - m_grpTCExecDT;

			butClose.Top = y - m_butCloseDT;
			butError.Top = y - m_butErrorDT;
			butNext.Top = y - m_butNextDT;
			butStartStop.Top = y - m_butStartStopDT;

			txtStat.Top = y - m_txtStatDT;
			comboLog.Top = y - m_comboLogDT;
		}


		// ------------------------------
		private void ctxtMenuResFiles_Popup(object sender, System.EventArgs e) {
		
			if( lstResFiles.SelectedIndex <  0 ) {

				ctxtResFileRem.Enabled = false;
			}
			else {

				ctxtResFileRem.Enabled = true;
			}
		}

		// ------------------------------
		private void ctxtResFileAdd_Click(object sender, System.EventArgs e) {
		
			System.ComponentModel.CancelEventHandler fileOkHandler;

			fileOkHandler = new System.ComponentModel.CancelEventHandler( fileOKHdlr4ResFile );

			doDialForAnyType( fileOkHandler );
		}

		// ------------------------------
		private void ctxtResFileRem_Click(object sender, System.EventArgs e) {

			int ix;

			Ref2File r2f;

			string blobUID;

			ix = lstResFiles.SelectedIndex; 

			if( ix > -1 ) {

				r2f = m_ResFilesLst[ix];

				blobUID = r2f.RefUID;

				if( blobUID.Length > 0 ) {
					
					// #######################
					// delete Blob?!
				}

				m_ResFilesLst.RemoveAt( ix );

				lstResFiles.Items.RemoveAt( ix );
			}		
		}

		// ----------------------
		private void ctxtMenuProc_Popup(object sender, System.EventArgs e) {
		
			if( lstTstProcFile.SelectedIndex <  0 ) {

				ctxtProcOpen.Enabled = false;
				ctxtProcName2Clip.Enabled = false;
			}
			else {

				ctxtProcOpen.Enabled = true;
				ctxtProcName2Clip.Enabled = true;
			}
		}

		// ----------------------------
		private void ctxtProcOpen_Click(object sender, System.EventArgs e) {

			try {

				int ix;

				Ref2File r2f;

				string filePthName;

				ix = lstTstProcFile.SelectedIndex;

				r2f = m_TProcLst[ix];

				filePthName = r2f.FName;
			
 				m_QNTools.openFile( filePthName );
			}
			catch( Exception exc ) {
			
				handleExcp( exc );
			}
		}

		// ----------------------------
		private void ctxtProcName2Clip_Click(object sender, System.EventArgs e) {
			
			int ix;

			Ref2File r2f;

			string filePthName;

			ix = lstTstProcFile.SelectedIndex;

			r2f = m_TProcLst[ix];

			filePthName = r2f.FName;
		
			Clipboard.SetDataObject( filePthName );
		}

		// ----------------------------
		private void ctxtMenuTstRef_Popup(object sender, System.EventArgs e) {
		
			if( lstTstRefFile.SelectedIndex <  0 ) {

				ctxtTstRefOpen.Enabled = false;
				ctxtTstRefName2Clip.Enabled = false;
			}
			else {

				ctxtTstRefOpen.Enabled = true;
				ctxtTstRefName2Clip.Enabled = true;
			}
		}

		// ----------------------------
		private void ctxtTstRefOpen_Click(object sender, System.EventArgs e) {

			try {

				int ix;

				Ref2File r2f;

				string filePthName;

				ix = lstTstRefFile.SelectedIndex;

				r2f = m_TRefLst[ix];

				filePthName = r2f.FName;
			
				m_QNTools.openFile( filePthName );	
			}
			catch( Exception exc ) {
			
				handleExcp( exc );
			}
		}

		// ----------------------------
		private void ctxtTstRefName2Clip_Click(object sender, System.EventArgs e) {
		
			int ix;

			Ref2File r2f;

			string filePthName;

			ix = lstTstRefFile.SelectedIndex;

			r2f = m_TRefLst[ix];

			filePthName = r2f.FName;
		
			Clipboard.SetDataObject( filePthName );
		}

		#endregion
	}
}
